@@ -13,26 +13,44 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "gstflacelements.h"
+#include "gstflacenc.h"
+#include "gstflacdec.h"
+#include "gstflactag.h"
+
+#include <gst/tag/tag.h>
+#include <gst/gst-i18n-plugin.h>
 
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  gboolean ret = FALSE;
+#ifdef ENABLE_NLS
+  GST_DEBUG ("binding text domain %s to locale dir %s", GETTEXT_PACKAGE,
+      LOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
 
-  ret |= GST_ELEMENT_REGISTER (flacdec, plugin);
-  ret |= GST_ELEMENT_REGISTER (flacenc, plugin);
-  ret |= GST_ELEMENT_REGISTER (flactag, plugin);
+  if (!gst_element_register (plugin, "flacenc", GST_RANK_PRIMARY,
+          GST_TYPE_FLAC_ENC))
+    return FALSE;
+  if (!gst_element_register (plugin, "flacdec", GST_RANK_PRIMARY,
+          GST_TYPE_FLAC_DEC))
+    return FALSE;
+  if (!gst_element_register (plugin, "flactag", GST_RANK_PRIMARY,
+          gst_flac_tag_get_type ()))
+    return FALSE;
 
-  return ret;
+  gst_tag_register_musicbrainz_tags ();
+
+  return TRUE;
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
