@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 
@@ -59,7 +59,6 @@ struct _GstFlacDec {
   guint16        min_blocksize;
   guint16        max_blocksize;
 
-  gboolean       do_resync;
   gint           error_count;
 };
 
