@@ -15,7 +15,7 @@
  *
  *  You should have received a copy of the GNU Lesser General Public
  *  License along with gst-pulse; if not, write to the Free Software
- *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  *  USA.
  */
 
@@ -23,19 +23,33 @@
 #include "config.h"
 #endif
 
-#include "gstpulseelements.h"
+#include <gst/gst-i18n-plugin.h>
+
+#include "pulsesink.h"
+#include "pulsesrc.h"
+
+GST_DEBUG_CATEGORY (pulse_debug);
 
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  gboolean ret = FALSE;
+#ifdef ENABLE_NLS
+  GST_DEBUG ("binding text domain %s to locale dir %s", GETTEXT_PACKAGE,
+      LOCALEDIR);
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+#endif
 
-  ret |= GST_ELEMENT_REGISTER (pulsesink, plugin);
-  ret |= GST_ELEMENT_REGISTER (pulsesrc, plugin);
+  if (!gst_element_register (plugin, "pulsesink", GST_RANK_PRIMARY + 10,
+          GST_TYPE_PULSESINK))
+    return FALSE;
 
-  ret |= GST_DEVICE_PROVIDER_REGISTER (pulsedeviceprovider, plugin);
+  if (!gst_element_register (plugin, "pulsesrc", GST_RANK_PRIMARY + 10,
+          GST_TYPE_PULSESRC))
+    return FALSE;
 
-  return ret;
+  GST_DEBUG_CATEGORY_INIT (pulse_debug, "pulse", 0, "PulseAudio elements");
+  return TRUE;
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
