@@ -1,6 +1,5 @@
 /* GStreamer
  * Copyright (C) 2011 David Schleef <ds@entropywave.com>
- * Copyright (C) 2021 Igalia S.L.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,22 +13,26 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef _GST_SOUP_HTTP_CLIENT_SINK_H_
 #define _GST_SOUP_HTTP_CLIENT_SINK_H_
 
-#include "gstsouploader.h"
-#include "gstsouputils.h"
 #include <gst/base/gstbasesink.h>
+#include <libsoup/soup.h>
 
 G_BEGIN_DECLS
 
-#define GST_TYPE_SOUP_HTTP_CLIENT_SINK (gst_soup_http_client_sink_get_type())
-G_DECLARE_FINAL_TYPE (GstSoupHttpClientSink, gst_soup_http_client_sink,
-    GST, SOUP_HTTP_CLIENT_SINK, GstBaseSink)
+#define GST_TYPE_SOUP_HTTP_CLIENT_SINK           (gst_soup_http_client_sink_get_type())
+#define GST_SOUP_HTTP_CLIENT_SINK(obj)           (G_TYPE_CHECK_INSTANCE_CAST((obj),GST_TYPE_SOUP_HTTP_CLIENT_SINK,GstSoupHttpClientSink))
+#define GST_SOUP_HTTP_CLIENT_SINK_CLASS(klass)   (G_TYPE_CHECK_CLASS_CAST((klass),GST_TYPE_SOUP_HTTP_CLIENT_SINK,GstSoupHttpClientSinkClass))
+#define GST_IS_SOUP_HTTP_CLIENT_SINK(obj)        (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_SOUP_HTTP_CLIENT_SINK))
+#define GST_IS_SOUP_HTTP_CLIENT_SINK_CLASS(obj)  (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_SOUP_HTTP_CLIENT_SINK))
+
+typedef struct _GstSoupHttpClientSink GstSoupHttpClientSink;
+typedef struct _GstSoupHttpClientSinkClass GstSoupHttpClientSinkClass;
 
 struct _GstSoupHttpClientSink
 {
@@ -40,37 +43,39 @@ struct _GstSoupHttpClientSink
   GMainContext *context;
   GMainLoop *loop;
   GThread *thread;
-  GSource *timer;
   SoupMessage *message;
   SoupSession *session;
   GList *queued_buffers;
   GList *sent_buffers;
   GList *streamheader_buffers;
-  GBytes *request_body;
 
   int status_code;
   char *reason_phrase;
 
   guint64 offset;
   int timeout;
-  gint failures;
 
   /* properties */
   SoupSession *prop_session;
   char *location;
   char *user_id;
   char *user_pw;
-  GstSoupUri *proxy;
+  SoupURI *proxy;
   char *proxy_id;
   char *proxy_pw;
   char *user_agent;
   gboolean automatic_redirect;
   gchar **cookies;
-  SoupLoggerLogLevel log_level;
-  gint retry_delay;
-  gint retries;
+
 };
 
+struct _GstSoupHttpClientSinkClass
+{
+  GstBaseSinkClass base_souphttpsink_class;
+};
+
+GType gst_soup_http_client_sink_get_type (void);
+
 G_END_DECLS
 
 #endif
