@@ -14,19 +14,17 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  * 
  */
 
 /**
  * SECTION:element-audioiirfilter
- * @title: audioiirfilter
  *
- * audioiirfilter implements a generic audio
- * [IIR filter](http://en.wikipedia.org/wiki/Infinite_impulse_response).
- * Before usage the "a" and "b" properties have to be set to the filter
- * coefficients that should be used.
+ * audioiirfilter implements a generic audio <ulink url="http://en.wikipedia.org/wiki/Infinite_impulse_response">IIR filter</ulink>. Before usage the
+ * "a" and "b" properties have to be set to the filter coefficients that
+ * should be used.
  *
  * The filter coefficients describe the numerator and denominator of the
  * transfer function.
@@ -35,11 +33,12 @@
  * "rate-changed" signal can be used. This should be done for most
  * IIR filters as they're depending on the sampling rate.
  *
- * ## Example application
- * <programlisting language="C">
+ * <refsect2>
+ * <title>Example application</title>
+ * |[
  * <xi:include xmlns:xi="http://www.w3.org/2003/XInclude" parse="text" href="../../../../tests/examples/audiofx/iirfilter-example.c" />
  * ]|
- *
+ * </refsect2>
  */
 
 /* FIXME 0.11: suppress warnings for deprecated API such as GValueArray
@@ -80,8 +79,6 @@ static guint gst_audio_iir_filter_signals[LAST_SIGNAL] = { 0, };
 #define gst_audio_iir_filter_parent_class parent_class
 G_DEFINE_TYPE (GstAudioIIRFilter, gst_audio_iir_filter,
     GST_TYPE_AUDIO_FX_BASE_IIR_FILTER);
-GST_ELEMENT_REGISTER_DEFINE (audioiirfilter, "audioiirfilter",
-    GST_RANK_NONE, GST_TYPE_AUDIO_IIR_FILTER);
 
 static void gst_audio_iir_filter_set_property (GObject * object, guint prop_id,
     const GValue * value, GParamSpec * pspec);
@@ -189,7 +186,7 @@ static void
 gst_audio_iir_filter_init (GstAudioIIRFilter * self)
 {
   GValue v = { 0, };
-  GValueArray *a;
+  GValueArray *a, *b;
 
   a = g_value_array_new (1);
 
@@ -198,7 +195,8 @@ gst_audio_iir_filter_init (GstAudioIIRFilter * self)
   g_value_array_append (a, &v);
   g_value_unset (&v);
 
-  gst_audio_iir_filter_update_coefficients (self, a, g_value_array_copy (a));
+  b = NULL;
+  gst_audio_iir_filter_update_coefficients (self, a, b);
 
   g_mutex_init (&self->lock);
 }
