@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,7 +49,6 @@ static gboolean gst_iir_equalizer_setup (GstAudioFilter * filter,
     const GstAudioInfo * info);
 static GstFlowReturn gst_iir_equalizer_transform_ip (GstBaseTransform * btrans,
     GstBuffer * buf);
-static void set_passthrough (GstIirEqualizer * equ);
 
 #define ALLOWED_CAPS \
     "audio/x-raw,"                                                \
@@ -160,7 +159,6 @@ gst_iir_equalizer_band_set_property (GObject * object, guint prop_id,
         BANDS_LOCK (equ);
         equ->need_new_coefficients = TRUE;
         band->gain = gain;
-        set_passthrough (equ);
         BANDS_UNLOCK (equ);
         GST_DEBUG_OBJECT (band, "changed gain = %lf ", band->gain);
       }
@@ -272,8 +270,6 @@ gst_iir_equalizer_band_class_init (GstIirEqualizerBandClass * klass)
           "Filter type", GST_TYPE_IIR_EQUALIZER_BAND_TYPE,
           BAND_TYPE_PEAK,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS | GST_PARAM_CONTROLLABLE));
-
-  gst_type_mark_as_plugin_api (GST_TYPE_IIR_EQUALIZER, 0);
 }
 
 static void
@@ -325,7 +321,7 @@ gst_iir_equalizer_child_proxy_get_child_by_index (GstChildProxy * child_proxy,
     g_return_val_if_fail (index < equ->freq_band_count, NULL);
   }
 
-  ret = g_object_ref (G_OBJECT (equ->bands[index]));
+  ret = g_object_ref (equ->bands[index]);
   BANDS_UNLOCK (equ);
 
   GST_LOG_OBJECT (equ, "return child[%d] %" GST_PTR_FORMAT, index, ret);
@@ -366,7 +362,6 @@ gst_iir_equalizer_class_init (GstIirEqualizerClass * klass)
   gobject_class->finalize = gst_iir_equalizer_finalize;
   audio_filter_class->setup = gst_iir_equalizer_setup;
   btrans_class->transform_ip = gst_iir_equalizer_transform_ip;
-  btrans_class->transform_ip_on_passthrough = FALSE;
 
   caps = gst_caps_from_string (ALLOWED_CAPS);
   gst_audio_filter_class_add_pad_templates (audio_filter_class, caps);
@@ -377,8 +372,7 @@ static void
 gst_iir_equalizer_init (GstIirEqualizer * eq)
 {
   g_mutex_init (&eq->bands_lock);
-  /* Band gains are 0 by default, passthrough until they are changed */
-  gst_base_transform_set_passthrough (GST_BASE_TRANSFORM (eq), TRUE);
+  eq->need_new_coefficients = TRUE;
 }
 
 static void
@@ -837,6 +831,9 @@ gst_iir_equalizer_transform_ip (GstBaseTransform * btrans, GstBuffer * buf)
   need_new_coefficients = equ->need_new_coefficients;
   BANDS_UNLOCK (equ);
 
+  if (!need_new_coefficients && gst_base_transform_is_passthrough (btrans))
+    return GST_FLOW_OK;
+
   timestamp = GST_BUFFER_TIMESTAMP (buf);
   timestamp =
       gst_segment_to_stream_time (&btrans->segment, GST_FORMAT_TIME, timestamp);
@@ -857,6 +854,7 @@ gst_iir_equalizer_transform_ip (GstBaseTransform * btrans, GstBuffer * buf)
   BANDS_LOCK (equ);
   if (need_new_coefficients) {
     update_coefficients (equ);
+    set_passthrough (equ);
   }
   BANDS_UNLOCK (equ);
 
@@ -893,12 +891,29 @@ gst_iir_equalizer_setup (GstAudioFilter * audio, const GstAudioInfo * info)
   return TRUE;
 }
 
-void
-equalizer_element_init (GstPlugin * plugin)
+
+static gboolean
+plugin_init (GstPlugin * plugin)
 {
-  static gsize res = FALSE;
-  if (g_once_init_enter (&res)) {
-    GST_DEBUG_CATEGORY_INIT (equalizer_debug, "equalizer", 0, "equalizer");
-    g_once_init_leave (&res, TRUE);
-  }
+  GST_DEBUG_CATEGORY_INIT (equalizer_debug, "equalizer", 0, "equalizer");
+
+  if (!(gst_element_register (plugin, "equalizer-nbands", GST_RANK_NONE,
+              GST_TYPE_IIR_EQUALIZER_NBANDS)))
+    return FALSE;
+
+  if (!(gst_element_register (plugin, "equalizer-3bands", GST_RANK_NONE,
+              GST_TYPE_IIR_EQUALIZER_3BANDS)))
+    return FALSE;
+
+  if (!(gst_element_register (plugin, "equalizer-10bands", GST_RANK_NONE,
+              GST_TYPE_IIR_EQUALIZER_10BANDS)))
+    return FALSE;
+
+  return TRUE;
 }
+
+GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
+    GST_VERSION_MINOR,
+    equalizer,
+    "GStreamer audio equalizers",
+    plugin_init, VERSION, GST_LICENSE, GST_PACKAGE_NAME, GST_PACKAGE_ORIGIN)
