@@ -1,6 +1,5 @@
 /* gstgoom.c: implementation of goom drawing element
  * Copyright (C) <2001> Richard Boulton <richard@tartarus.org>
- * Copyright (C) <2015> Luis de Bethencourt <luis@debethencourt.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -14,19 +13,19 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_GOOM_H__
 #define __GST_GOOM_H__
 
-#include <gst/pbutils/gstaudiovisualizer.h>
-
-#include "goom.h"
-
 G_BEGIN_DECLS
 
+#include <gst/gst.h>
+#include <gst/base/gstadapter.h>
+#include "goom.h"
+
 #define GOOM_SAMPLES 512
 
 #define GST_TYPE_GOOM            (gst_goom_get_type())
@@ -40,26 +39,49 @@ typedef struct _GstGoomClass GstGoomClass;
 
 struct _GstGoom
 {
-  GstAudioVisualizer parent;
+  GstElement element;
+
+  /* pads */
+  GstPad *sinkpad, *srcpad;
+  GstAdapter *adapter;
 
   /* input tracking */
+  gint rate;
   gint channels;
+  guint bps;
 
   /* video state */
+  gint fps_n;
+  gint fps_d;
   gint width;
   gint height;
+  GstClockTime duration;
+  guint outsize;
+  GstBufferPool *pool;
+
+  /* samples per frame */
+  guint spf;
+  /* bytes per frame */
+  guint bpf;
 
   /* goom stuff */
+  gint16 datain[2][GOOM_SAMPLES];
   PluginInfo *plugin;
+
+  /* segment state */
+  GstSegment segment;
+
+  /* QoS stuff *//* with LOCK */
+  gdouble proportion;
+  GstClockTime earliest_time;
 };
 
 struct _GstGoomClass
 {
-  GstAudioVisualizerClass parent_class;
+  GstElementClass parent_class;
 };
 
 GType gst_goom_get_type (void);
-gboolean gst_goom_plugin_init (GstPlugin * plugin);
 
 G_END_DECLS
 
