@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_IMAGE_FREEZE_H__
@@ -49,30 +49,16 @@ struct _GstImageFreeze
 
   GMutex lock;
   GstBuffer *buffer;
-  GstCaps *buffer_caps, *current_caps;
-
-  gboolean negotiated_framerate;
   gint fps_n, fps_d;
 
   GstSegment segment;
   gboolean need_segment;
-  guint seqnum;
-
-  gint num_buffers;
-  gint num_buffers_left;
-
-  gboolean allow_replace;
-
-  gboolean is_live;
-  gboolean blocked;
-  GCond blocked_cond;
-  GstClockID clock_id;
 
   guint64 offset;
 
-  gboolean flushing;
-  /* Indicates EOS received via send_event() */
-  gboolean direct_eos;
+  /* TRUE if currently doing a flushing seek, protected
+   * by srcpad's stream lock */
+  gint seeking;
 };
 
 struct _GstImageFreezeClass
@@ -82,8 +68,6 @@ struct _GstImageFreezeClass
 
 GType gst_image_freeze_get_type (void);
 
-GST_ELEMENT_REGISTER_DECLARE (imagefreeze);
-
 G_END_DECLS
 
 #endif /* __GST_IMAGE_FREEZE_H__ */
