@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 /*
  * Unless otherwise indicated, Source Code is licensed under MIT license.
@@ -43,16 +43,18 @@
 
 #include "gstqtmuxmap.h"
 #include "fourcc.h"
+#include "ftypcc.h"
 
 /* static info related to various format */
 
 #define COMMON_VIDEO_CAPS \
-  "width = (int) [ 16, MAX ], " \
-  "height = (int) [ 16, MAX ]"
+  "width = (int) [ 16, 4096 ], " \
+  "height = (int) [ 16, 4096 ], " \
+  "framerate = (fraction) [ 0, MAX ]"
 
 #define COMMON_VIDEO_CAPS_NO_FRAMERATE \
-  "width = (int) [ 16, MAX ], " \
-  "height = (int) [ 16, MAX ] "
+  "width = (int) [ 16, 4096 ], " \
+  "height = (int) [ 16, 4096 ] "
 
 #define H263_CAPS \
   "video/x-h263, " \
@@ -60,19 +62,7 @@
 
 #define H264_CAPS \
   "video/x-h264, " \
-  "stream-format = (string) { avc, avc3 }, " \
-  "alignment = (string) au, " \
-  COMMON_VIDEO_CAPS
-
-#define H265_CAPS \
-  "video/x-h265, " \
-  "stream-format = (string) { hvc1, hev1 }, " \
-  "alignment = (string) au, " \
-  COMMON_VIDEO_CAPS
-
-#define H266_CAPS \
-  "video/x-h266, " \
-  "stream-format = (string) { vvc1, vvi1 }, " \
+  "stream-format = (string) avc, " \
   "alignment = (string) au, " \
   COMMON_VIDEO_CAPS
 
@@ -85,77 +75,48 @@
   "divxversion = (int) 5, "\
   COMMON_VIDEO_CAPS
 
-#define PRORES_CAPS \
-  "video/x-prores, " \
-  "variant = (string) {standard, lt, hq, proxy, 4444, 4444xq}, " \
-  COMMON_VIDEO_CAPS
-
-#define CINEFORM_CAPS \
-  "video/x-cineform, " \
-  COMMON_VIDEO_CAPS
-
 #define SVQ_CAPS \
   "video/x-svq, " \
   "svqversion = (int) 3, " \
   COMMON_VIDEO_CAPS
 
-#define VP9_CAPS \
-  "video/x-vp9, " \
-  "profile = (string) { 0, 1, 2, 3 }, " \
-  "chroma-format = (string) { 4:2:0, 4:2:2, 4:4:4 }, " \
-  COMMON_VIDEO_CAPS
-
 #define COMMON_AUDIO_CAPS(c, r) \
   "channels = (int) [ 1, " G_STRINGIFY (c) " ], " \
   "rate = (int) [ 1, " G_STRINGIFY (r) " ]"
 
 #define PCM_CAPS \
   "audio/x-raw, " \
-  "format = (string) { S16LE, S16BE, S8, U8 }, " \
+  "format = (string) { S8, U8 }, " \
+  "layout = (string) interleaved, " \
+  COMMON_AUDIO_CAPS (2, MAX) "; " \
+  "audio/x-raw, " \
+  "format = (string) { S16LE, S16BE }, " \
   "layout = (string) interleaved, " \
   COMMON_AUDIO_CAPS (2, MAX)
 
 #define PCM_CAPS_FULL \
+  PCM_CAPS "; " \
   "audio/x-raw, " \
-  "format = (string) { S32LE, S32BE, S24LE, S24BE, S16LE, S16BE, S8, U8 }, " \
+  "format = (string) { S24LE, S24BE }, " \
+  "layout = (string) interleaved, " \
+  COMMON_AUDIO_CAPS (2, MAX) "; " \
+  "audio/x-raw, " \
+  "format = (string) { S32LE, S32BE }, " \
   "layout = (string) interleaved, " \
   COMMON_AUDIO_CAPS (2, MAX)
 
-#define PCM_CAPS_UNPOSITIONED \
-  "audio/x-raw, " \
-  "format = (string) { S32LE, S32BE, S24LE, S24BE, S16LE, S16BE, S8, U8 }, " \
-  "layout = (string) interleaved, " \
-  "channel-mask = (bitmask) 0, " \
-  COMMON_AUDIO_CAPS (16, MAX)
-
 #define MP3_CAPS \
   "audio/mpeg, " \
   "mpegversion = (int) 1, " \
   "layer = (int) 3, " \
   COMMON_AUDIO_CAPS (2, MAX)
 
-#define MP123_CAPS \
-  "audio/mpeg, " \
-  "mpegversion = (int) 1, " \
-  "layer = (int) [1, 3], " \
-  COMMON_AUDIO_CAPS (2, MAX)
-
 #define AAC_CAPS \
   "audio/mpeg, " \
   "mpegversion = (int) 4, " \
   "stream-format = (string) raw, " \
   COMMON_AUDIO_CAPS (8, MAX)
 
-#define AC3_CAPS \
-  "audio/x-ac3, " \
-  COMMON_AUDIO_CAPS (6, MAX)
-
-#define EAC3_CAPS \
-  "audio/x-eac3, " \
-  "alignment = (string) iec61937, " \
-  "parsed = (boolean) true, " \
-  COMMON_AUDIO_CAPS (16, MAX)
-
 #define AMR_CAPS \
   "audio/AMR, " \
   "rate = (int) 8000, " \
@@ -174,21 +135,6 @@
   "audio/x-alac, " \
   COMMON_AUDIO_CAPS(2, MAX)
 
-#define OPUS_CAPS \
-  "audio/x-opus, " \
-  "channel-mapping-family = (int) [0, 255], " \
-  COMMON_AUDIO_CAPS(8, MAX)
-
-
-#define TEXT_UTF8 \
-  "text/x-raw, " \
-  "format=(string)utf8"
-
-#define CEA608_CAPS \
-  "closedcaption/x-cea-608, format=(string)s334-1a"
-#define CEA708_CAPS \
-  "closedcaption/x-cea-708, format=(string)cdp"
-
 /* FIXME 0.11 - take a look at bugs #580005 and #340375 */
 GstQTMuxFormatProp gst_qt_mux_format_list[] = {
   /* original QuickTime format; see Apple site (e.g. qtff.pdf) */
@@ -201,37 +147,29 @@ GstQTMuxFormatProp gst_qt_mux_format_list[] = {
         GST_STATIC_CAPS ("video/quicktime, variant = (string) apple; "
             "video/quicktime"),
         GST_STATIC_CAPS ("video/x-raw, "
-            "format = (string) { RGB, UYVY, v210 }, "
+            "format = (string) { RGB, UYVY }, "
             COMMON_VIDEO_CAPS "; "
             MPEG4V_CAPS "; "
-            PRORES_CAPS "; "
-            CINEFORM_CAPS "; "
             H263_CAPS "; "
             H264_CAPS "; "
-            H265_CAPS "; "
-            H266_CAPS "; "
             SVQ_CAPS "; "
             "video/x-dv, "
             "systemstream = (boolean) false, "
             COMMON_VIDEO_CAPS "; "
             "image/jpeg, "
             COMMON_VIDEO_CAPS_NO_FRAMERATE "; "
-            "image/png, "
-            COMMON_VIDEO_CAPS_NO_FRAMERATE "; "
             "video/x-vp8, "
             COMMON_VIDEO_CAPS "; "
-            VP9_CAPS "; "
             "video/x-dirac, "
-            COMMON_VIDEO_CAPS "; " "video/x-qt-part, " COMMON_VIDEO_CAPS "; "
-            "video/x-av1, " "stream-format = (string) \"obu-stream\", "
-            "alignment = (string) \"tu\", " COMMON_VIDEO_CAPS ";"),
-        GST_STATIC_CAPS (PCM_CAPS_FULL "; " PCM_CAPS_UNPOSITIONED " ; "
-            MP123_CAPS " ; " AAC_CAPS " ; " AC3_CAPS " ; "
-            ADPCM_CAPS " ; " "audio/x-alaw, " COMMON_AUDIO_CAPS (2,
-                MAX) "; " "audio/x-mulaw, " COMMON_AUDIO_CAPS (2,
-                MAX) "; " AMR_CAPS " ; " ALAC_CAPS " ; " OPUS_CAPS),
-        GST_STATIC_CAPS (TEXT_UTF8),
-      GST_STATIC_CAPS (CEA608_CAPS "; " CEA708_CAPS)}
+            COMMON_VIDEO_CAPS "; " "video/x-qt-part, " COMMON_VIDEO_CAPS),
+        GST_STATIC_CAPS (PCM_CAPS_FULL "; "
+            MP3_CAPS " ; "
+            AAC_CAPS " ; "
+            ADPCM_CAPS " ; "
+            "audio/x-alaw, " COMMON_AUDIO_CAPS (2, MAX) "; "
+            "audio/x-mulaw, " COMMON_AUDIO_CAPS (2, MAX) "; "
+            AMR_CAPS " ; " ALAC_CAPS)
+      }
   ,
   /* ISO 14496-14: mp42 as ISO base media extension
    * (supersedes original ISO 144996-1 mp41) */
@@ -242,15 +180,10 @@ GstQTMuxFormatProp gst_qt_mux_format_list[] = {
         "MP4",
         "GstMP4Mux",
         GST_STATIC_CAPS ("video/quicktime, variant = (string) iso"),
-        GST_STATIC_CAPS (MPEG4V_CAPS "; " H264_CAPS ";" H265_CAPS ";" H266_CAPS
-            ";" "video/x-mp4-part," COMMON_VIDEO_CAPS "; " "video/x-av1, "
-            "stream-format = (string) \"obu-stream\", "
-            "alignment = (string) \"tu\", " COMMON_VIDEO_CAPS "; " VP9_CAPS
-            "; "),
-        GST_STATIC_CAPS (MP123_CAPS "; " AAC_CAPS " ; " AC3_CAPS " ; " EAC3_CAPS
-            " ; " ALAC_CAPS " ; " OPUS_CAPS),
-        GST_STATIC_CAPS (TEXT_UTF8),
-      GST_STATIC_CAPS_NONE}
+        GST_STATIC_CAPS (MPEG4V_CAPS "; " H264_CAPS ";"
+            "video/x-mp4-part," COMMON_VIDEO_CAPS),
+        GST_STATIC_CAPS (MP3_CAPS "; " AAC_CAPS " ; " ALAC_CAPS)
+      }
   ,
   /* Microsoft Smooth Streaming fmp4/isml */
   /* TODO add WMV/WMA support */
@@ -262,9 +195,8 @@ GstQTMuxFormatProp gst_qt_mux_format_list[] = {
         "GstISMLMux",
         GST_STATIC_CAPS ("video/quicktime, variant = (string) iso-fragmented"),
         GST_STATIC_CAPS (MPEG4V_CAPS "; " H264_CAPS),
-        GST_STATIC_CAPS (MP3_CAPS "; " AAC_CAPS),
-        GST_STATIC_CAPS_NONE,
-      GST_STATIC_CAPS_NONE}
+        GST_STATIC_CAPS (MP3_CAPS "; " AAC_CAPS)
+      }
   ,
   /* 3GPP Technical Specification 26.244 V7.3.0
    * (extended in 3GPP2 File Formats for Multimedia Services) */
@@ -276,9 +208,8 @@ GstQTMuxFormatProp gst_qt_mux_format_list[] = {
         "Gst3GPPMux",
         GST_STATIC_CAPS ("video/quicktime, variant = (string) 3gpp"),
         GST_STATIC_CAPS (H263_CAPS "; " MPEG4V_CAPS "; " H264_CAPS),
-        GST_STATIC_CAPS (AMR_CAPS "; " MP3_CAPS "; " AAC_CAPS "; " AC3_CAPS),
-        GST_STATIC_CAPS (TEXT_UTF8),
-      GST_STATIC_CAPS_NONE}
+        GST_STATIC_CAPS (AMR_CAPS "; " MP3_CAPS "; " AAC_CAPS)
+      }
   ,
   /* ISO 15444-3: Motion-JPEG-2000 (also ISO base media extension) */
   {
@@ -290,9 +221,8 @@ GstQTMuxFormatProp gst_qt_mux_format_list[] = {
         GST_STATIC_CAPS ("video/mj2"),
         GST_STATIC_CAPS ("image/x-j2c, " COMMON_VIDEO_CAPS "; "
             "image/x-jpc, " COMMON_VIDEO_CAPS),
-        GST_STATIC_CAPS (PCM_CAPS),
-        GST_STATIC_CAPS_NONE,
-      GST_STATIC_CAPS_NONE}
+        GST_STATIC_CAPS (PCM_CAPS)
+      }
   ,
   {
         GST_QT_MUX_FORMAT_NONE,
@@ -315,12 +245,11 @@ gst_qt_mux_map_format_to_flavor (GstQTMuxFormat format)
 
 static void
 gst_qt_mux_map_check_tracks (AtomMOOV * moov, gint * _video, gint * _audio,
-    gboolean * _has_h264, gboolean * _has_dolby)
+    gboolean * _has_h264)
 {
   GList *it;
   gint video = 0, audio = 0;
   gboolean has_h264 = FALSE;
-  gboolean has_dolby = FALSE;
 
   for (it = moov->traks; it != NULL; it = g_list_next (it)) {
     AtomTRAK *track = it->data;
@@ -329,11 +258,8 @@ gst_qt_mux_map_check_tracks (AtomMOOV * moov, gint * _video, gint * _audio,
       video++;
       if (track->is_h264)
         has_h264 = TRUE;
-    } else {
+    } else
       audio++;
-      if (track->is_ac3 || track->is_eac3)
-        has_dolby = TRUE;
-    }
   }
 
   if (_video)
@@ -342,8 +268,6 @@ gst_qt_mux_map_check_tracks (AtomMOOV * moov, gint * _video, gint * _audio,
     *_audio = audio;
   if (_has_h264)
     *_has_h264 = has_h264;
-  if (_has_dolby)
-    *_has_dolby = has_dolby;
 }
 
 /* pretty static, but possibly dynamic format info */
@@ -358,15 +282,14 @@ gst_qt_mux_map_format_to_header (GstQTMuxFormat format, GstBuffer ** _prefix,
     guint32 * _major, guint32 * _version, GList ** _compatible, AtomMOOV * moov,
     GstClockTime longest_chunk, gboolean faststart)
 {
-  static const guint32 qt_brands[] = { 0 };
-  static const guint32 mp4_brands[] =
-      { FOURCC_mp41, FOURCC_isom, FOURCC_iso2, 0 };
-  static const guint32 isml_brands[] = { FOURCC_iso2, 0 };
-  static const guint32 gpp_brands[] = { FOURCC_isom, FOURCC_iso2, 0 };
-  static const guint32 mjp2_brands[] = { FOURCC_isom, FOURCC_iso2, 0 };
-  static const guint8 mjp2_prefix[] =
+  static guint32 qt_brands[] = { 0 };
+  static guint32 mp4_brands[] = { FOURCC_mp41, FOURCC_isom, FOURCC_iso2, 0 };
+  static guint32 isml_brands[] = { FOURCC_iso2, 0 };
+  static guint32 gpp_brands[] = { FOURCC_isom, FOURCC_iso2, 0 };
+  static guint32 mjp2_brands[] = { FOURCC_isom, FOURCC_iso2, 0 };
+  static guint8 mjp2_prefix[] =
       { 0, 0, 0, 12, 'j', 'P', ' ', ' ', 0x0D, 0x0A, 0x87, 0x0A };
-  const guint32 *comp = NULL;
+  guint32 *comp = NULL;
   guint32 major = 0, version = 0;
   GstBuffer *prefix = NULL;
   GList *result = NULL;
@@ -385,13 +308,6 @@ gst_qt_mux_map_format_to_header (GstQTMuxFormat format, GstBuffer ** _prefix,
     case GST_QT_MUX_FORMAT_MP4:
       major = FOURCC_mp42;
       comp = mp4_brands;
-
-      gboolean has_dolby = FALSE;
-      gst_qt_mux_map_check_tracks (moov, NULL, NULL, NULL, &has_dolby);
-      if (has_dolby) {          /* Add Dolby brand for AC-3/E-AC-3 content */
-        result = g_list_append (result, GUINT_TO_POINTER (FOURCC_dby1));
-      }
-
       break;
     case GST_QT_MUX_FORMAT_ISML:
       major = FOURCC_isml;
@@ -402,7 +318,7 @@ gst_qt_mux_map_format_to_header (GstQTMuxFormat format, GstBuffer ** _prefix,
       gint video, audio;
       gboolean has_h264;
 
-      gst_qt_mux_map_check_tracks (moov, &video, &audio, &has_h264, NULL);
+      gst_qt_mux_map_check_tracks (moov, &video, &audio, &has_h264);
       /* only track restriction really matters for Basic Profile */
       if (video <= 1 && audio <= 1) {
         /* it seems only newer spec knows about H264 */
