@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_RTP_G729_PAY_H__
@@ -59,6 +59,8 @@ struct _GstRTPG729PayClass
 
 GType gst_rtp_g729_pay_get_type (void);
 
+gboolean gst_rtp_g729_pay_plugin_init (GstPlugin * plugin);
+
 G_END_DECLS
 
 #endif /* __GST_RTP_G729_PAY_H__ */
