@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_RTP_GST_DEPAY_H__
@@ -47,9 +47,6 @@ struct _GstRtpGSTDepay
   GstAdapter *adapter;
   guint current_CV;
   GstCaps *CV_cache[8];
-
-  GstTagList *tags;
-  gchar *stream_id;
 };
 
 struct _GstRtpGSTDepayClass
