@@ -19,8 +19,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,10 +30,7 @@
 #include <string.h>
 
 #include <gst/rtp/gstrtpbuffer.h>
-#include <gst/video/video.h>
-#include "gstrtpelements.h"
 #include "gstrtph263depay.h"
-#include "gstrtputils.h"
 
 GST_DEBUG_CATEGORY_STATIC (rtph263depay_debug);
 #define GST_CAT_DEFAULT (rtph263depay_debug)
@@ -57,24 +54,16 @@ static GstStaticPadTemplate gst_rtp_h263_depay_sink_template =
     GST_STATIC_CAPS ("application/x-rtp, "
         "media = (string) \"video\", "
         "payload = (int) " GST_RTP_PAYLOAD_H263_STRING ", "
-        "clock-rate = (int) 90000; "
-        /* optional SDP attribute:
-         * "a-framesize = (string) \"1234-1234\", "
-         */
+        "clock-rate = (int) 90000, " "encoding-name = (string) \"H263\"; "
         "application/x-rtp, "
         "media = (string) \"video\", "
-        "clock-rate = (int) 90000, " "encoding-name = (string) \"H263\""
-        /* optional SDP attribute:
-         * "a-framesize = (string) \"1234-1234\", "
-         */
-    )
+        "payload = (int) " GST_RTP_PAYLOAD_DYNAMIC_STRING ", "
+        "clock-rate = (int) 90000, " "encoding-name = (string) \"H263\"")
     );
 
 #define gst_rtp_h263_depay_parent_class parent_class
 G_DEFINE_TYPE (GstRtpH263Depay, gst_rtp_h263_depay,
     GST_TYPE_RTP_BASE_DEPAYLOAD);
-GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (rtph263depay, "rtph263depay",
-    GST_RANK_SECONDARY, GST_TYPE_RTP_H263_DEPAY, rtp_element_init (plugin));
 
 static void gst_rtp_h263_depay_finalize (GObject * object);
 
@@ -82,7 +71,7 @@ static GstStateChangeReturn gst_rtp_h263_depay_change_state (GstElement *
     element, GstStateChange transition);
 
 static GstBuffer *gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload,
-    GstRTPBuffer * rtp);
+    GstBuffer * buf);
 gboolean gst_rtp_h263_depay_setcaps (GstRTPBaseDepayload * filter,
     GstCaps * caps);
 
@@ -104,10 +93,10 @@ gst_rtp_h263_depay_class_init (GstRtpH263DepayClass * klass)
 
   gstelement_class->change_state = gst_rtp_h263_depay_change_state;
 
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_rtp_h263_depay_src_template);
-  gst_element_class_add_static_pad_template (gstelement_class,
-      &gst_rtp_h263_depay_sink_template);
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_rtp_h263_depay_src_template));
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&gst_rtp_h263_depay_sink_template));
 
   gst_element_class_set_static_metadata (gstelement_class,
       "RTP H263 depayloader", "Codec/Depayloader/Network/RTP",
@@ -115,7 +104,7 @@ gst_rtp_h263_depay_class_init (GstRtpH263DepayClass * klass)
       "Philippe Kalaf <philippe.kalaf@collabora.co.uk>, "
       "Edward Hervey <bilboed@bilboed.com>");
 
-  gstrtpbasedepayload_class->process_rtp_packet = gst_rtp_h263_depay_process;
+  gstrtpbasedepayload_class->process = gst_rtp_h263_depay_process;
   gstrtpbasedepayload_class->set_caps = gst_rtp_h263_depay_setcaps;
 }
 
@@ -126,9 +115,6 @@ gst_rtp_h263_depay_init (GstRtpH263Depay * rtph263depay)
 
   rtph263depay->offset = 0;
   rtph263depay->leftover = 0;
-
-  gst_rtp_base_depayload_set_aggregate_hdrext_enabled (GST_RTP_BASE_DEPAYLOAD
-      (rtph263depay), TRUE);
 }
 
 static void
@@ -144,67 +130,20 @@ gst_rtp_h263_depay_finalize (GObject * object)
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
-static gboolean
-gst_rtp_h263_parse_framesize (GstRTPBaseDepayload * filter,
-    const gchar * media_attr, GstCaps * srccaps)
-{
-  gchar *dimension, *endptr;
-  gint width, height;
-  GstStructure *d;
-
-  width = g_ascii_strtoull (media_attr, &endptr, 10);
-  if (width <= 0) {
-    GST_ERROR_OBJECT (filter,
-        "Framesize media attribute width out of valid range");
-    return FALSE;
-  } else if (*endptr != '-') {
-    GST_ERROR_OBJECT (filter,
-        "Framesize media attribute has invalid dimension separator");
-    return FALSE;
-  }
-
-  dimension = endptr + 1;
-  height = g_ascii_strtoull (dimension, &endptr, 10);
-  if (height <= 0) {
-    GST_ERROR_OBJECT (filter,
-        "Framesize media attribute height out of valid range");
-    return FALSE;
-  } else if (*endptr != '\0') {
-    GST_ERROR_OBJECT (filter,
-        "Framesize media attribute unexpectedly has trailing characters");
-    return FALSE;
-  }
-
-  d = gst_caps_get_structure (srccaps, 0);
-  gst_structure_set (d, "width", G_TYPE_INT, width, "height", G_TYPE_INT,
-      height, NULL);
-
-  return TRUE;
-}
-
 gboolean
 gst_rtp_h263_depay_setcaps (GstRTPBaseDepayload * filter, GstCaps * caps)
 {
   GstCaps *srccaps;
   GstStructure *structure = gst_caps_get_structure (caps, 0);
   gint clock_rate;
-  const gchar *framesize;
-
-  srccaps = gst_caps_new_simple ("video/x-h263",
-      "variant", G_TYPE_STRING, "itu",
-      "h263version", G_TYPE_STRING, "h263", NULL);
 
   if (!gst_structure_get_int (structure, "clock-rate", &clock_rate))
     clock_rate = 90000;         /* default */
   filter->clock_rate = clock_rate;
 
-  framesize = gst_structure_get_string (structure, "a-framesize");
-  if (framesize != NULL) {
-    if (!gst_rtp_h263_parse_framesize (filter, framesize, srccaps)) {
-      return FALSE;
-    }
-  }
-
+  srccaps = gst_caps_new_simple ("video/x-h263",
+      "variant", G_TYPE_STRING, "itu",
+      "h263version", G_TYPE_STRING, "h263", NULL);
   gst_pad_set_caps (GST_RTP_BASE_DEPAYLOAD_SRCPAD (filter), srccaps);
   gst_caps_unref (srccaps);
 
@@ -212,7 +151,7 @@ gst_rtp_h263_depay_setcaps (GstRTPBaseDepayload * filter, GstCaps * caps)
 }
 
 static GstBuffer *
-gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
+gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstBuffer * buf)
 {
   GstRtpH263Depay *rtph263depay;
   GstBuffer *outbuf;
@@ -222,11 +161,12 @@ gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
   guint SBIT, EBIT;
   gboolean F, P, M;
   gboolean I;
+  GstRTPBuffer rtp = { NULL };
 
   rtph263depay = GST_RTP_H263_DEPAY (depayload);
 
   /* flush remaining data on discont */
-  if (GST_BUFFER_IS_DISCONT (rtp->buffer)) {
+  if (GST_BUFFER_IS_DISCONT (buf)) {
     GST_LOG_OBJECT (depayload, "Discont buffer, flushing adapter");
     gst_adapter_clear (rtph263depay->adapter);
     rtph263depay->offset = 0;
@@ -234,13 +174,12 @@ gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
     rtph263depay->start = FALSE;
   }
 
-  payload_len = gst_rtp_buffer_get_payload_len (rtp);
-  payload = gst_rtp_buffer_get_payload (rtp);
+  gst_rtp_buffer_map (buf, GST_MAP_READ, &rtp);
 
-  M = gst_rtp_buffer_get_marker (rtp);
+  payload_len = gst_rtp_buffer_get_payload_len (&rtp);
+  payload = gst_rtp_buffer_get_payload (&rtp);
 
-  if (payload_len < 1)
-    goto too_small;
+  M = gst_rtp_buffer_get_marker (&rtp);
 
   /* Let's see what mode we are using */
   F = (payload[0] & 0x80) == 0x80;
@@ -263,8 +202,6 @@ gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
      * |F|P|SBIT |EBIT | SRC |I|U|S|A|R      |DBQ| TRB |    TR         |
      * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
      */
-    if (payload_len <= header_len)
-      goto too_small;
     I = (payload[1] & 0x10) == 0x10;
   } else {
     if (P == 0) {
@@ -281,8 +218,6 @@ gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
        * |I|U|S|A| HMV1        | VMV1        | HMV2        | VMV2        |
        * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
        */
-      if (payload_len <= header_len)
-        goto too_small;
       I = (payload[4] & 0x80) == 0x80;
     } else {
       /* F == 1 and P == 1
@@ -300,8 +235,6 @@ gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
        * | RR                                  |DBQ| TRB |    TR         |
        * +-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+-+
        */
-      if (payload_len <= header_len)
-        goto too_small;
       I = (payload[4] & 0x80) == 0x80;
     }
   }
@@ -316,12 +249,11 @@ gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
   payload_len -= header_len;
 
   if (!rtph263depay->start) {
-    /* only mode A should be used when there is a picture start code, but
-     * buggy payloaders may send mode B/C in start of frame */
-    if (payload_len > 4 && (GST_READ_UINT32_BE (payload) >> 10 == 0x20)) {
-      GST_DEBUG ("Mode %c with PSC => frame start", "ABC"[F + P]);
+    /* do not skip this fragment if it is a Mode A with picture start code */
+    if (!F && payload_len > 4 && (GST_READ_UINT32_BE (payload) >> 10 == 0x20)) {
+      GST_DEBUG ("Mode A with PSC => frame start");
       rtph263depay->start = TRUE;
-      if ((!!(payload[4] & 0x02)) != I) {
+      if (! !(payload[4] & 0x02) != I) {
         GST_DEBUG ("Wrong Picture Coding Type Flag in rtp header");
         I = !I;
       }
@@ -352,13 +284,13 @@ gst_rtp_h263_depay_process (GstRTPBaseDepayload * depayload, GstRTPBuffer * rtp)
     GstBuffer *tmp;
 
     /* Take the entire buffer */
-    tmp = gst_rtp_buffer_get_payload_subbuffer (rtp, header_len, payload_len);
+    tmp = gst_rtp_buffer_get_payload_subbuffer (&rtp, header_len, payload_len);
     gst_adapter_push (rtph263depay->adapter, tmp);
   } else {
     GstBuffer *tmp;
 
     /* Take the entire buffer except for the last byte */
-    tmp = gst_rtp_buffer_get_payload_subbuffer (rtp, header_len,
+    tmp = gst_rtp_buffer_get_payload_subbuffer (&rtp, header_len,
         payload_len - 1);
     gst_adapter_push (rtph263depay->adapter, tmp);
 
@@ -393,8 +325,6 @@ skip:
 
       GST_DEBUG ("Pushing out a buffer of %d bytes", avail);
 
-      gst_rtp_drop_non_video_meta (rtph263depay, outbuf);
-
       gst_rtp_base_depayload_push (depayload, outbuf);
       rtph263depay->offset = 0;
       rtph263depay->leftover = 0;
@@ -403,16 +333,9 @@ skip:
       rtph263depay->start = TRUE;
     }
   }
+  gst_rtp_buffer_unmap (&rtp);
 
   return NULL;
-
-too_small:
-  {
-    GST_ELEMENT_WARNING (rtph263depay, STREAM, DECODE,
-        ("Packet payload was too small"), (NULL));
-    gst_rtp_base_depayload_dropped (depayload);
-    return NULL;
-  }
 }
 
 static GstStateChangeReturn
@@ -445,3 +368,10 @@ gst_rtp_h263_depay_change_state (GstElement * element,
   }
   return ret;
 }
+
+gboolean
+gst_rtp_h263_depay_plugin_init (GstPlugin * plugin)
+{
+  return gst_element_register (plugin, "rtph263depay",
+      GST_RANK_SECONDARY, GST_TYPE_RTP_H263_DEPAY);
+}
