@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_RTP_VORBIS_DEPAY_H__
@@ -63,6 +63,8 @@ struct _GstRtpVorbisDepayClass
 
 GType gst_rtp_vorbis_depay_get_type (void);
 
+gboolean gst_rtp_vorbis_depay_plugin_init (GstPlugin * plugin);
+
 G_END_DECLS
 
 #endif /* __GST_RTP_VORBIS_DEPAY_H__ */
