@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 /**
@@ -94,7 +94,8 @@ enum
   PROP_BORDER,
   PROP_DEPTH,
   PROP_POSITION,
-  PROP_INVERT
+  PROP_INVERT,
+  PROP_LAST,
 };
 
 #define AYUV_SIZE(w,h)     ((w) * (h) * 4)
@@ -190,6 +191,8 @@ gst_smpte_alpha_class_init (GstSMPTEAlphaClass * klass)
    * GstSMPTEAlpha:invert:
    *
    * Set to TRUE to invert the transition mask (ie. flip it horizontally).
+   *
+   * Since: 0.10.23
    */
   g_object_class_install_property (G_OBJECT_CLASS (klass), PROP_INVERT,
       g_param_spec_boolean ("invert", "Invert",
@@ -615,20 +618,22 @@ gst_smpte_alpha_set_info (GstVideoFilter * vfilter, GstCaps * incaps,
 {
   GstSMPTEAlpha *smpte = GST_SMPTE_ALPHA (vfilter);
   gboolean ret;
+  gint width, height;
 
   smpte->process = NULL;
+
   smpte->in_format = GST_VIDEO_INFO_FORMAT (in_info);
   smpte->out_format = GST_VIDEO_INFO_FORMAT (out_info);
+  smpte->width = width = GST_VIDEO_INFO_WIDTH (out_info);
+  smpte->height = height = GST_VIDEO_INFO_HEIGHT (out_info);
 
   /* try to update the mask now, this will also adjust the width/height on
    * success */
   GST_OBJECT_LOCK (smpte);
   ret =
       gst_smpte_alpha_update_mask (smpte, smpte->type, smpte->invert,
-      smpte->depth, GST_VIDEO_INFO_WIDTH (out_info),
-      GST_VIDEO_INFO_HEIGHT (out_info));
+      smpte->depth, width, height);
   GST_OBJECT_UNLOCK (smpte);
-
   if (!ret)
     goto mask_failed;
 
