@@ -15,42 +15,87 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 /**
  * SECTION:element-spectrum
- * @title: spectrum
  *
  * The Spectrum element analyzes the frequency spectrum of an audio signal.
- * If the #GstSpectrum:post-messages property is %TRUE, it sends analysis results
+ * If the #GstSpectrum:post-messages property is #TRUE, it sends analysis results
  * as element messages named
- * `spectrum` after each interval of time given
+ * <classname>&quot;spectrum&quot;</classname> after each interval of time given
  * by the #GstSpectrum:interval property.
  *
  * The message's structure contains some combination of these fields:
- *
- * * #GstClockTime `timestamp`: the timestamp of the buffer that triggered the message.
- * * #GstClockTime `stream-time`: the stream time of the buffer.
- * * #GstClockTime `running-time`: the running_time of the buffer.
- * * #GstClockTime `duration`: the duration of the buffer.
- * * #GstClockTime `endtime`: the end time of the buffer that triggered the message as stream time (this
+ * <itemizedlist>
+ * <listitem>
+ *   <para>
+ *   #GstClockTime
+ *   <classname>&quot;timestamp&quot;</classname>:
+ *   the timestamp of the buffer that triggered the message.
+ *   </para>
+ * </listitem>
+ * <listitem>
+ *   <para>
+ *   #GstClockTime
+ *   <classname>&quot;stream-time&quot;</classname>:
+ *   the stream time of the buffer.
+ *   </para>
+ * </listitem>
+ * <listitem>
+ *   <para>
+ *   #GstClockTime
+ *   <classname>&quot;running-time&quot;</classname>:
+ *   the running_time of the buffer.
+ *   </para>
+ * </listitem>
+ * <listitem>
+ *   <para>
+ *   #GstClockTime
+ *   <classname>&quot;duration&quot;</classname>:
+ *   the duration of the buffer.
+ *   </para>
+ * </listitem>
+ * <listitem>
+ *   <para>
+ *   #GstClockTime
+ *   <classname>&quot;endtime&quot;</classname>:
+ *   the end time of the buffer that triggered the message as stream time (this
  *   is deprecated, as it can be calculated from stream-time + duration)
- * * A #GST_TYPE_LIST value of #gfloat `magnitude`: the level for each frequency band in dB.
- *   All values below the value of the
+ *   </para>
+ * </listitem>
+ * <listitem>
+ *   <para>
+ *   #GstValueList of #gfloat
+ *   <classname>&quot;magnitude&quot;</classname>:
+ *   the level for each frequency band in dB. All values below the value of the
  *   #GstSpectrum:threshold property will be set to the threshold. Only present
  *   if the #GstSpectrum:message-magnitude property is %TRUE.
- * * A #GST_TYPE_LIST of #gfloat `phase`: The phase for each frequency band. The value is between -pi and pi. Only
+ *   </para>
+ * </listitem>
+ * <listitem>
+ *   <para>
+ *   #GstValueList of #gfloat
+ *   <classname>&quot;phase&quot;</classname>:
+ *   The phase for each frequency band. The value is between -pi and pi. Only
  *   present if the #GstSpectrum:message-phase property is %TRUE.
+ *   </para>
+ * </listitem>
+ * </itemizedlist>
  *
  * If #GstSpectrum:multi-channel property is set to true. magnitude and phase
- * fields will be each a nested #GST_TYPE_ARRAY value. The first dimension are the
+ * fields will be each a nested #GstValueArray. The first dimension are the
  * channels and the second dimension are the values.
  *
- * ## Example application
- *
- * {{ tests/examples/spectrum/spectrum-example.c }}
+ * <refsect2>
+ * <title>Example application</title>
+ * |[
+ * <xi:include xmlns:xi="http://www.w3.org/2003/XInclude" parse="text" href="../../../../tests/examples/spectrum/spectrum-example.c" />
+ * ]|
+ * </refsect2>
  *
+ * Last reviewed on 2011-03-10 (0.10.29)
  */
 
 #ifdef HAVE_CONFIG_H
@@ -65,8 +110,11 @@ GST_DEBUG_CATEGORY_STATIC (gst_spectrum_debug);
 #define GST_CAT_DEFAULT gst_spectrum_debug
 
 /* elementfactory information */
-#define FORMATS "{ " GST_AUDIO_NE (S16) ", " GST_AUDIO_NE (S24) ", " \
-    GST_AUDIO_NE (S32) ", " GST_AUDIO_NE (F32) ", " GST_AUDIO_NE (F64) " }"
+#if G_BYTE_ORDER == G_LITTLE_ENDIAN
+# define FORMATS "{ S16LE, S24LE, S32LE, F32LE, F64LE }"
+#else
+# define FORMATS "{ S16BE, S24BE, S32BE, F32BE, F64BE }"
+#endif
 
 #define ALLOWED_CAPS \
   GST_AUDIO_CAPS_MAKE (FORMATS) ", " \
@@ -95,8 +143,6 @@ enum
 
 #define gst_spectrum_parent_class parent_class
 G_DEFINE_TYPE (GstSpectrum, gst_spectrum, GST_TYPE_AUDIO_FILTER);
-GST_ELEMENT_REGISTER_DEFINE (spectrum, "spectrum", GST_RANK_NONE,
-    GST_TYPE_SPECTRUM);
 
 static void gst_spectrum_finalize (GObject * object);
 static void gst_spectrum_set_property (GObject * object, guint prop_id,
@@ -130,6 +176,13 @@ gst_spectrum_class_init (GstSpectrumClass * klass)
 
   filter_class->setup = GST_DEBUG_FUNCPTR (gst_spectrum_setup);
 
+  /**
+   * GstSpectrum:post-messages
+   *
+   * Post messages on the bus with spectrum information.
+   *
+   * Since: 0.10.17
+   */
   g_object_class_install_property (gobject_class, PROP_POST_MESSAGES,
       g_param_spec_boolean ("post-messages", "Post Messages",
           "Whether to post a 'spectrum' element message on the bus for each "
@@ -157,7 +210,7 @@ gst_spectrum_class_init (GstSpectrumClass * klass)
 
   g_object_class_install_property (gobject_class, PROP_BANDS,
       g_param_spec_uint ("bands", "Bands", "Number of frequency bands",
-          2, ((guint) G_MAXINT + 2) / 2, DEFAULT_BANDS,
+          0, G_MAXUINT, DEFAULT_BANDS,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
   g_object_class_install_property (gobject_class, PROP_THRESHOLD,
@@ -166,6 +219,13 @@ gst_spectrum_class_init (GstSpectrumClass * klass)
           G_MININT, 0, DEFAULT_THRESHOLD,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
+  /**
+   * GstSpectrum:multi-channel
+   *
+   * Send separate results for each channel
+   *
+   * Since: 0.10.29
+   */
   g_object_class_install_property (gobject_class, PROP_MULTI_CHANNEL,
       g_param_spec_boolean ("multi-channel", "Multichannel results",
           "Send separate results for each channel",
@@ -702,7 +762,8 @@ gst_spectrum_message_new (GstSpectrum * spectrum, GstClockTime timestamp,
             spectrum->bands);
       }
       if (spectrum->message_phase) {
-        gst_spectrum_message_add_array (pcv, cd->spect_phase, spectrum->bands);
+        gst_spectrum_message_add_array (pcv, cd->spect_magnitude,
+            spectrum->bands);
       }
     }
   }
@@ -952,8 +1013,8 @@ gst_spectrum_transform_ip (GstBaseTransform * trans, GstBuffer * buffer)
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-
-  return GST_ELEMENT_REGISTER (spectrum, plugin);
+  return gst_element_register (plugin, "spectrum", GST_RANK_NONE,
+      GST_TYPE_SPECTRUM);
 }
 
 GST_PLUGIN_DEFINE (GST_VERSION_MAJOR,
