@@ -15,32 +15,28 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 /**
  * SECTION:element-udpsink
- * @title: udpsink
  * @see_also: udpsrc, multifdsink
  *
  * udpsink is a network sink that sends UDP packets to the network.
  * It can be combined with RTP payloaders to implement RTP streaming.
  *
- * ## Examples
+ * <refsect2>
+ * <title>Examples</title>
  * |[
  * gst-launch-1.0 -v audiotestsrc ! udpsink
  * ]|
- *
+ * </refsect2>
  */
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
-#include "gstudpelements.h"
 #include "gstudpsink.h"
 
-GST_DEBUG_CATEGORY_EXTERN (multiudpsink_debug);
-#define GST_CAT_DEFAULT (multiudpsink_debug)
-
 #define UDP_DEFAULT_HOST        "localhost"
 #define UDP_DEFAULT_PORT        5004
 
@@ -74,8 +70,6 @@ static void gst_udpsink_get_property (GObject * object, guint prop_id,
 #define gst_udpsink_parent_class parent_class
 G_DEFINE_TYPE_WITH_CODE (GstUDPSink, gst_udpsink, GST_TYPE_MULTIUDPSINK,
     G_IMPLEMENT_INTERFACE (GST_TYPE_URI_HANDLER, gst_udpsink_uri_handler_init));
-GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (udpsink, "udpsink", GST_RANK_NONE,
-    GST_TYPE_UDPSINK, udp_element_init (plugin));
 
 static void
 gst_udpsink_class_init (GstUDPSinkClass * klass)
@@ -131,18 +125,11 @@ gst_udpsink_finalize (GstUDPSink * udpsink)
 static gboolean
 gst_udpsink_set_uri (GstUDPSink * sink, const gchar * uri, GError ** error)
 {
-  gchar *host;
-  guint16 port;
-
   gst_multiudpsink_remove (GST_MULTIUDPSINK (sink), sink->host, sink->port);
 
-  if (!gst_udp_parse_uri (uri, &host, &port, NULL))
+  if (!gst_udp_parse_uri (uri, &sink->host, &sink->port))
     goto wrong_uri;
 
-  g_free (sink->host);
-  sink->host = host;
-  sink->port = port;
-
   g_free (sink->uri);
   sink->uri = g_strdup (uri);
 
