@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifndef __GST_VIDEO_CROP_H__
@@ -23,6 +23,7 @@
 #include <gst/video/gstvideofilter.h>
 
 G_BEGIN_DECLS
+
 #define GST_TYPE_VIDEO_CROP \
   (gst_video_crop_get_type())
 #define GST_VIDEO_CROP(obj) \
@@ -34,24 +35,10 @@ G_BEGIN_DECLS
 #define GST_IS_VIDEO_CROP_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_VIDEO_CROP))
 
-GST_ELEMENT_REGISTER_DECLARE (videocrop);
-
-typedef enum
-{
-  /* RGB (+ variants), ARGB (+ variants), AYUV, GRAY */
-  VIDEO_CROP_PIXEL_FORMAT_PACKED_SIMPLE = 0,
-  /* YVYU, YUY2, UYVY */
-  VIDEO_CROP_PIXEL_FORMAT_PACKED_COMPLEX,
-  /* I420, A420, YV12, Y444, Y42B, Y41B,
-   * I420_10BE, A420_10BE, Y444_10BE, A444_10BE, I422_10BE, A422_10BE,
-   * I420_10LE, A420_10LE, Y444_10LE, A444_10LE, I422_10LE, A422_10LE,
-   * I420_12BE, Y444_12BE, I422_12BE,
-   * I420_12LE, Y444_12LE, I422_12LE,
-   * GBR, GBR_10BE, GBR_10LE, GBR_12BE, GBR_12LE,
-   * GBRA, GBRA_10BE, GBRA_10LE, GBRA_12BE, GBRA_12LE */
-  VIDEO_CROP_PIXEL_FORMAT_PLANAR,
-  /* NV12, NV21 */
-  VIDEO_CROP_PIXEL_FORMAT_SEMI_PLANAR
+typedef enum {
+  VIDEO_CROP_PIXEL_FORMAT_PACKED_SIMPLE = 0,  /* RGBx, AYUV */
+  VIDEO_CROP_PIXEL_FORMAT_PACKED_COMPLEX,     /* UYVY, YVYU */
+  VIDEO_CROP_PIXEL_FORMAT_PLANAR              /* I420, YV12 */
 } VideoCropPixelFormat;
 
 typedef struct _GstVideoCropImageDetails GstVideoCropImageDetails;
@@ -63,25 +50,16 @@ struct _GstVideoCrop
 {
   GstVideoFilter parent;
 
-  /*< private > */
-  gint prop_left;
-  gint prop_right;
-  gint prop_top;
-  gint prop_bottom;
-  gboolean need_update;
-
-  GstVideoInfo in_info;
-  GstVideoInfo out_info;
-
+  /*< private >*/
   gint crop_left;
   gint crop_right;
   gint crop_top;
   gint crop_bottom;
 
-  VideoCropPixelFormat packing;
+  VideoCropPixelFormat  packing;
   gint macro_y_off;
 
-  gboolean raw_caps;
+  GMutex lock;
 };
 
 struct _GstVideoCropClass
@@ -92,4 +70,6 @@ struct _GstVideoCropClass
 GType gst_video_crop_get_type (void);
 
 G_END_DECLS
+
 #endif /* __GST_VIDEO_CROP_H__ */
+
