@@ -16,8 +16,8 @@
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
-* Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
-* Boston, MA 02110-1301, USA.
+* Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+* Boston, MA 02111-1307, USA.
 * 
 *
 * The development of this code was made possible due to the involvement
@@ -30,19 +30,15 @@
 #endif
 
 #include "gstdirectsoundsink.h"
-#include "gstdirectsounddevice.h"
+
 
 static gboolean
 plugin_init (GstPlugin * plugin)
 {
-  if (!gst_element_register (plugin, "directsoundsink", GST_RANK_MARGINAL,
+  if (!gst_element_register (plugin, "directsoundsink", GST_RANK_PRIMARY,
           GST_TYPE_DIRECTSOUND_SINK))
     return FALSE;
 
-  if (!gst_device_provider_register (plugin, "directsoundsinkdeviceprovider",
-          GST_RANK_NONE, GST_TYPE_DIRECTSOUND_DEVICE_PROVIDER))
-    return FALSE;
-
   return TRUE;
 }
 
