@@ -13,22 +13,22 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 /**
  * SECTION:element-oss4sink
- * @title: oss4sink
  *
  * This element lets you output sound using the Open Sound System (OSS)
  * version 4.
- *
+ * 
  * Note that you should almost always use generic audio conversion elements
  * like audioconvert and audioresample in front of an audiosink to make sure
  * your pipeline works under all circumstances (those conversion elements will
  * act in passthrough-mode if no conversion is necessary).
- *
- * ## Example pipelines
+ * 
+ * <refsect2>
+ * <title>Example pipelines</title>
  * |[
  * gst-launch-1.0 -v audiotestsrc ! audioconvert ! volume volume=0.1 ! oss4sink
  * ]| will output a sine wave (continuous beep sound) to your sound card (with
@@ -37,7 +37,9 @@
  * gst-launch-1.0 -v filesrc location=music.ogg ! decodebin ! audioconvert ! audioresample ! oss4sink
  * ]| will play an Ogg/Vorbis audio file and output it using the Open Sound System
  * version 4.
+ * </refsect2>
  *
+ * Since: 0.10.7
  */
 
 #ifdef HAVE_CONFIG_H
@@ -52,7 +54,7 @@
 #include <unistd.h>
 #include <string.h>
 
-#include <glib/gi18n-lib.h>
+#include <gst/gst-i18n-plugin.h>
 #include <gst/audio/streamvolume.h>
 
 #define NO_LEGACY_MIXER
@@ -104,8 +106,6 @@ enum
 #define gst_oss4_sink_parent_class parent_class
 G_DEFINE_TYPE_WITH_CODE (GstOss4Sink, gst_oss4_sink,
     GST_TYPE_AUDIO_SINK, G_IMPLEMENT_INTERFACE (GST_TYPE_STREAM_VOLUME, NULL));
-GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (oss4sink, "oss4sink",
-    GST_RANK_SECONDARY + 1, GST_TYPE_OSS4_SINK, oss4_element_init (plugin));
 
 static void
 gst_oss4_sink_dispose (GObject * object)
@@ -545,13 +545,7 @@ non_block:
 static gboolean
 gst_oss4_sink_open_func (GstAudioSink * asink)
 {
-  if (!gst_oss4_sink_open (asink, FALSE))
-    return FALSE;
-
-  /* the initial volume might not be the property default, so notify
-   * application to make it get a reading of the current volume */
-  g_object_notify (G_OBJECT (asink), "volume");
-  return TRUE;
+  return gst_oss4_sink_open (asink, FALSE);
 }
 
 static gboolean
