@@ -39,8 +39,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -48,7 +48,6 @@
 #endif
 
 #include <gst/gst.h>
-#include <glib/gi18n-lib.h>
 #include <gst/audio/audio-channels.h>
 #include "gstosxaudioringbuffer.h"
 #include "gstosxaudiosink.h"
@@ -62,6 +61,7 @@ GST_DEBUG_CATEGORY_STATIC (osx_audio_debug);
 #include "gstosxcoreaudio.h"
 
 static void gst_osx_audio_ring_buffer_dispose (GObject * object);
+static void gst_osx_audio_ring_buffer_finalize (GObject * object);
 static gboolean gst_osx_audio_ring_buffer_open_device (GstAudioRingBuffer *
     buf);
 static gboolean gst_osx_audio_ring_buffer_close_device (GstAudioRingBuffer *
@@ -87,14 +87,17 @@ static void
 gst_osx_audio_ring_buffer_class_init (GstOsxAudioRingBufferClass * klass)
 {
   GObjectClass *gobject_class;
+  GstObjectClass *gstobject_class;
   GstAudioRingBufferClass *gstringbuffer_class;
 
   gobject_class = (GObjectClass *) klass;
+  gstobject_class = (GstObjectClass *) klass;
   gstringbuffer_class = (GstAudioRingBufferClass *) klass;
 
   ring_parent_class = g_type_class_peek_parent (klass);
 
   gobject_class->dispose = gst_osx_audio_ring_buffer_dispose;
+  gobject_class->finalize = gst_osx_audio_ring_buffer_finalize;
 
   gstringbuffer_class->open_device =
       GST_DEBUG_FUNCPTR (gst_osx_audio_ring_buffer_open_device);
@@ -121,6 +124,7 @@ gst_osx_audio_ring_buffer_class_init (GstOsxAudioRingBufferClass * klass)
 static void
 gst_osx_audio_ring_buffer_init (GstOsxAudioRingBuffer * ringbuffer)
 {
+  ringbuffer->core_audio = gst_core_audio_new (GST_OBJECT (ringbuffer));
 }
 
 static void
@@ -130,29 +134,27 @@ gst_osx_audio_ring_buffer_dispose (GObject * object)
 
   osxbuf = GST_OSX_AUDIO_RING_BUFFER (object);
 
-  g_clear_object (&osxbuf->core_audio);
+  if (osxbuf->core_audio) {
+    g_object_unref (osxbuf->core_audio);
+    osxbuf->core_audio = NULL;
+  }
   G_OBJECT_CLASS (ring_parent_class)->dispose (object);
 }
 
+static void
+gst_osx_audio_ring_buffer_finalize (GObject * object)
+{
+  G_OBJECT_CLASS (ring_parent_class)->finalize (object);
+}
+
 static gboolean
 gst_osx_audio_ring_buffer_open_device (GstAudioRingBuffer * buf)
 {
-  GstObject *osxel = GST_OBJECT_PARENT (buf);
-  GstOsxAudioRingBuffer *osxbuf = GST_OSX_AUDIO_RING_BUFFER (buf);
+  GstOsxAudioRingBuffer *osxbuf;
 
-  if (!gst_core_audio_select_device (osxbuf->core_audio)) {
-    GST_ELEMENT_ERROR (osxel, RESOURCE, NOT_FOUND,
-        (_("CoreAudio device not found")), (NULL));
-    return FALSE;
-  }
+  osxbuf = GST_OSX_AUDIO_RING_BUFFER (buf);
 
-  if (!gst_core_audio_open (osxbuf->core_audio)) {
-    GST_ELEMENT_ERROR (osxel, RESOURCE, OPEN_READ,
-        (_("CoreAudio device could not be opened")), (NULL));
-    return FALSE;
-  }
-
-  return TRUE;
+  return gst_core_audio_open (osxbuf->core_audio);
 }
 
 static gboolean
@@ -169,9 +171,10 @@ gst_osx_audio_ring_buffer_acquire (GstAudioRingBuffer * buf,
     GstAudioRingBufferSpec * spec)
 {
   gboolean ret = FALSE, is_passthrough = FALSE;
-  GstOsxAudioRingBuffer *osxbuf = GST_OSX_AUDIO_RING_BUFFER (buf);
-  AudioStreamBasicDescription format = { 0 };
-  guint32 frames_per_packet = 0;
+  GstOsxAudioRingBuffer *osxbuf;
+  AudioStreamBasicDescription format;
+
+  osxbuf = GST_OSX_AUDIO_RING_BUFFER (buf);
 
   if (RINGBUFFER_IS_SPDIF (spec->type)) {
     format.mFormatID = kAudioFormat60958AC3;
@@ -205,12 +208,10 @@ gst_osx_audio_ring_buffer_acquire (GstAudioRingBuffer * buf,
       } else {
         format.mFormatFlags |= kAudioFormatFlagIsAlignedHigh;
       }
+      if (GST_AUDIO_INFO_IS_BIG_ENDIAN (&spec->info)) {
+        format.mFormatFlags |= kAudioFormatFlagIsBigEndian;
+      }
     }
-
-    if (GST_AUDIO_INFO_IS_BIG_ENDIAN (&spec->info)) {
-      format.mFormatFlags |= kAudioFormatFlagIsBigEndian;
-    }
-
     format.mBytesPerFrame = GST_AUDIO_INFO_BPF (&spec->info);
     format.mBitsPerChannel = depth;
     format.mBytesPerPacket = GST_AUDIO_INFO_BPF (&spec->info);
@@ -220,23 +221,22 @@ gst_osx_audio_ring_buffer_acquire (GstAudioRingBuffer * buf,
         (spec->latency_time * GST_AUDIO_INFO_RATE (&spec->info) /
         G_USEC_PER_SEC) * GST_AUDIO_INFO_BPF (&spec->info);
     spec->segtotal = spec->buffer_time / spec->latency_time;
-    frames_per_packet = spec->segsize / GST_AUDIO_INFO_BPF (&spec->info);
-
     is_passthrough = FALSE;
   }
 
   GST_DEBUG_OBJECT (osxbuf, "Format: " CORE_AUDIO_FORMAT,
       CORE_AUDIO_FORMAT_ARGS (format));
 
-  /* gst_audio_ring_buffer_set_channel_positions is not called
-   * since the AUs perform channel reordering themselves.
-   * (see gst_core_audio_set_channel_layout) */
+  if (GST_IS_OSX_AUDIO_SINK (GST_OBJECT_PARENT (buf))) {
+    gst_audio_ring_buffer_set_channel_positions (buf,
+        GST_OSX_AUDIO_SINK (GST_OBJECT_PARENT (buf))->channel_positions);
+  }
 
   buf->size = spec->segtotal * spec->segsize;
   buf->memory = g_malloc0 (buf->size);
 
   ret = gst_core_audio_initialize (osxbuf->core_audio, format, spec->caps,
-      frames_per_packet, is_passthrough);
+      is_passthrough);
 
   if (!ret) {
     g_free (buf->memory);
@@ -256,7 +256,7 @@ gst_osx_audio_ring_buffer_release (GstAudioRingBuffer * buf)
 
   osxbuf = GST_OSX_AUDIO_RING_BUFFER (buf);
 
-  gst_core_audio_uninitialize (osxbuf->core_audio);
+  gst_core_audio_unitialize (osxbuf->core_audio);
 
   g_free (buf->memory);
   buf->memory = NULL;
@@ -309,5 +309,7 @@ gst_osx_audio_ring_buffer_delay (GstAudioRingBuffer * buf)
           GST_AUDIO_INFO_RATE (&buf->spec.info), &samples, &latency)) {
     return 0;
   }
+  GST_DEBUG_OBJECT (buf, "Got latency: %f seconds -> %d samples",
+      latency, samples);
   return samples;
 }
