@@ -67,10 +67,9 @@
 #endif
 
 #include <gst/gst.h>
-#include <gst/audio/multichannel.h>
+#include <gst/audio/audio.h>
+#include <gst/audio/audio-channels.h>
 #include <gst/audio/gstaudioiec61937.h>
-#include <CoreAudio/CoreAudio.h>
-#include <CoreAudio/AudioHardware.h>
 
 #include "gstosxaudiosink.h"
 #include "gstosxaudioelement.h"
@@ -96,43 +95,20 @@ enum
 
 #define DEFAULT_VOLUME 1.0
 
+#if (G_BYTE_ORDER == G_LITTLE_ENDIAN)
+# define FORMATS "{ S32LE, S24LE, S16LE, U8 }"
+#else
+# define FORMATS "{ S32BE, S24BE, S16BE, U8 }"
+#endif
+
 static GstStaticPadTemplate sink_factory = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
-    GST_STATIC_CAPS ("audio/x-raw-float, "
-        "endianness = (int) {" G_STRINGIFY (G_BYTE_ORDER) " }, "
-        "signed = (boolean) { TRUE }, "
-        "width = (int) 32, "
-        "depth = (int) 32, "
+    GST_STATIC_CAPS ("audio/x-raw, "
+        "format = (string) " FORMATS ", "
+        "layout = (string) interleaved, "
         "rate = (int) [1, MAX], "
         "channels = (int) [1, 9];"
-        "audio/x-raw-int, "
-        "endianness = (int) {" G_STRINGIFY (G_BYTE_ORDER) " }, "
-        "signed = (boolean) { TRUE }, "
-        "width = (int) 32, "
-        "depth = (int) 32, "
-        "rate = (int) [1, MAX], "
-        "channels = (int) [1, 9];"
-        "audio/x-raw-int, "
-        "endianness = (int) {" G_STRINGIFY (G_BYTE_ORDER) " }, "
-        "signed = (boolean) { TRUE }, "
-        "width = (int) 24, "
-        "depth = (int) 24, "
-        "rate = (int) [1, MAX], "
-        "channels = (int) [1, 9];"
-        "audio/x-raw-int, "
-        "endianness = (int) {" G_STRINGIFY (G_BYTE_ORDER) " }, "
-        "signed = (boolean) { TRUE }, "
-        "width = (int) 16, "
-        "depth = (int) 16, "
-        "rate = (int) [1, MAX], "
-        "channels = (int) [1, 9];"
-        "audio/x-raw-int, "
-        "endianness = (int) {" G_STRINGIFY (G_BYTE_ORDER) " }, "
-        "signed = (boolean) { TRUE }, "
-        "width = (int) 8, "
-        "depth = (int) 8, "
-        "rate = (int) [1, MAX], " "channels = (int) [1, MAX];"
         "audio/x-ac3, framed = (boolean) true;"
         "audio/x-dts, framed = (boolean) true")
     );
@@ -142,20 +118,24 @@ static void gst_osx_audio_sink_set_property (GObject * object, guint prop_id,
 static void gst_osx_audio_sink_get_property (GObject * object, guint prop_id,
     GValue * value, GParamSpec * pspec);
 
-static gboolean gst_osx_audio_sink_stop (GstBaseSink * base);
-static GstCaps *gst_osx_audio_sink_getcaps (GstBaseSink * base);
-static gboolean gst_osx_audio_sink_acceptcaps (GstPad * pad, GstCaps * caps);
+static gboolean gst_osx_audio_sink_query (GstBaseSink * base, GstQuery * query);
 
-static GstBuffer *gst_osx_audio_sink_sink_payload (GstBaseAudioSink * sink,
+static gboolean gst_osx_audio_sink_stop (GstBaseSink * base);
+static GstCaps *gst_osx_audio_sink_getcaps (GstBaseSink * base,
+    GstCaps * filter);
+static gboolean gst_osx_audio_sink_acceptcaps (GstOsxAudioSink * sink,
+    GstCaps * caps);
+
+static GstBuffer *gst_osx_audio_sink_sink_payload (GstAudioBaseSink * sink,
     GstBuffer * buf);
-static GstRingBuffer *gst_osx_audio_sink_create_ringbuffer (GstBaseAudioSink *
-    sink);
+static GstAudioRingBuffer
+    * gst_osx_audio_sink_create_ringbuffer (GstAudioBaseSink * sink);
 static void gst_osx_audio_sink_osxelement_init (gpointer g_iface,
     gpointer iface_data);
 static gboolean gst_osx_audio_sink_select_device (GstOsxAudioSink * osxsink);
 static void gst_osx_audio_sink_set_volume (GstOsxAudioSink * sink);
 
-static OSStatus gst_osx_audio_sink_io_proc (GstOsxRingBuffer * buf,
+static OSStatus gst_osx_audio_sink_io_proc (GstOsxAudioRingBuffer * buf,
     AudioUnitRenderActionFlags * ioActionFlags,
     const AudioTimeStamp * inTimeStamp,
     UInt32 inBusNumber, UInt32 inNumberFrames, AudioBufferList * bufferList);
@@ -171,27 +151,15 @@ gst_osx_audio_sink_do_init (GType type)
 
   GST_DEBUG_CATEGORY_INIT (osx_audiosink_debug, "osxaudiosink", 0,
       "OSX Audio Sink");
+  gst_core_audio_init_debug ();
   GST_DEBUG ("Adding static interface");
   g_type_add_interface_static (type, GST_OSX_AUDIO_ELEMENT_TYPE,
       &osxelement_info);
 }
 
-GST_BOILERPLATE_FULL (GstOsxAudioSink, gst_osx_audio_sink, GstBaseAudioSink,
-    GST_TYPE_BASE_AUDIO_SINK, gst_osx_audio_sink_do_init);
-
-static void
-gst_osx_audio_sink_base_init (gpointer g_class)
-{
-  GstElementClass *element_class = GST_ELEMENT_CLASS (g_class);
-
-  gst_element_class_add_pad_template (element_class,
-      gst_static_pad_template_get (&sink_factory));
-
-  gst_element_class_set_static_metadata (element_class, "Audio Sink (OSX)",
-      "Sink/Audio",
-      "Output to a sound card in OS X",
-      "Zaheer Abbas Merali <zaheerabbas at merali dot org>");
-}
+#define gst_osx_audio_sink_parent_class parent_class
+G_DEFINE_TYPE_WITH_CODE (GstOsxAudioSink, gst_osx_audio_sink,
+    GST_TYPE_AUDIO_BASE_SINK, gst_osx_audio_sink_do_init (g_define_type_id));
 
 static void
 gst_osx_audio_sink_class_init (GstOsxAudioSinkClass * klass)
@@ -199,21 +167,25 @@ gst_osx_audio_sink_class_init (GstOsxAudioSinkClass * klass)
   GObjectClass *gobject_class;
   GstElementClass *gstelement_class;
   GstBaseSinkClass *gstbasesink_class;
-  GstBaseAudioSinkClass *gstbaseaudiosink_class;
+  GstAudioBaseSinkClass *gstaudiobasesink_class;
 
   gobject_class = (GObjectClass *) klass;
   gstelement_class = (GstElementClass *) klass;
   gstbasesink_class = (GstBaseSinkClass *) klass;
-  gstbaseaudiosink_class = (GstBaseAudioSinkClass *) klass;
+  gstaudiobasesink_class = (GstAudioBaseSinkClass *) klass;
 
   parent_class = g_type_class_peek_parent (klass);
 
   gobject_class->set_property = gst_osx_audio_sink_set_property;
   gobject_class->get_property = gst_osx_audio_sink_get_property;
 
+#ifndef HAVE_IOS
   g_object_class_install_property (gobject_class, ARG_DEVICE,
       g_param_spec_int ("device", "Device ID", "Device ID of output device",
           0, G_MAXINT, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+#endif
+
+  gstbasesink_class->query = GST_DEBUG_FUNCPTR (gst_osx_audio_sink_query);
 
   g_object_class_install_property (gobject_class, ARG_VOLUME,
       g_param_spec_double ("volume", "Volume", "Volume of this stream",
@@ -222,15 +194,25 @@ gst_osx_audio_sink_class_init (GstOsxAudioSinkClass * klass)
   gstbasesink_class->get_caps = GST_DEBUG_FUNCPTR (gst_osx_audio_sink_getcaps);
   gstbasesink_class->stop = GST_DEBUG_FUNCPTR (gst_osx_audio_sink_stop);
 
-  gstbaseaudiosink_class->create_ringbuffer =
+  gstaudiobasesink_class->create_ringbuffer =
       GST_DEBUG_FUNCPTR (gst_osx_audio_sink_create_ringbuffer);
-  gstbaseaudiosink_class->payload =
+  gstaudiobasesink_class->payload =
       GST_DEBUG_FUNCPTR (gst_osx_audio_sink_sink_payload);
+
+  gst_element_class_add_pad_template (gstelement_class,
+      gst_static_pad_template_get (&sink_factory));
+
+  gst_element_class_set_static_metadata (gstelement_class, "Audio Sink (OSX)",
+      "Sink/Audio",
+      "Output to a sound card in OS X",
+      "Zaheer Abbas Merali <zaheerabbas at merali dot org>");
 }
 
 static void
-gst_osx_audio_sink_init (GstOsxAudioSink * sink, GstOsxAudioSinkClass * gclass)
+gst_osx_audio_sink_init (GstOsxAudioSink * sink)
 {
+  gint i;
+
   GST_DEBUG ("Initialising object");
 
   sink->device_id = kAudioDeviceUnknown;
@@ -238,8 +220,10 @@ gst_osx_audio_sink_init (GstOsxAudioSink * sink, GstOsxAudioSinkClass * gclass)
 
   sink->volume = DEFAULT_VOLUME;
 
-  gst_pad_set_acceptcaps_function (GST_BASE_SINK (sink)->sinkpad,
-      GST_DEBUG_FUNCPTR (gst_osx_audio_sink_acceptcaps));
+  sink->channels = 0;
+  for (i = 0; i < GST_OSX_AUDIO_MAX_CHANNEL; i++) {
+    sink->channel_positions[i] = GST_AUDIO_CHANNEL_POSITION_INVALID;
+  }
 }
 
 static void
@@ -249,9 +233,11 @@ gst_osx_audio_sink_set_property (GObject * object, guint prop_id,
   GstOsxAudioSink *sink = GST_OSX_AUDIO_SINK (object);
 
   switch (prop_id) {
+#ifndef HAVE_IOS
     case ARG_DEVICE:
       sink->device_id = g_value_get_int (value);
       break;
+#endif
     case ARG_VOLUME:
       sink->volume = g_value_get_double (value);
       gst_osx_audio_sink_set_volume (sink);
@@ -268,9 +254,11 @@ gst_osx_audio_sink_get_property (GObject * object, guint prop_id,
 {
   GstOsxAudioSink *sink = GST_OSX_AUDIO_SINK (object);
   switch (prop_id) {
+#ifndef HAVE_IOS
     case ARG_DEVICE:
       g_value_set_int (value, sink->device_id);
       break;
+#endif
     case ARG_VOLUME:
       g_value_set_double (value, sink->volume);
       break;
@@ -280,6 +268,30 @@ gst_osx_audio_sink_get_property (GObject * object, guint prop_id,
   }
 }
 
+static gboolean
+gst_osx_audio_sink_query (GstBaseSink * base, GstQuery * query)
+{
+  GstOsxAudioSink *sink = GST_OSX_AUDIO_SINK (base);
+  gboolean ret = FALSE;
+
+  switch (GST_QUERY_TYPE (query)) {
+    case GST_QUERY_ACCEPT_CAPS:
+    {
+      GstCaps *caps = NULL;
+
+      gst_query_parse_accept_caps (query, &caps);
+      ret = gst_osx_audio_sink_acceptcaps (sink, caps);
+      gst_query_set_accept_caps_result (query, ret);
+      ret = TRUE;
+      break;
+    }
+    default:
+      ret = GST_BASE_SINK_CLASS (parent_class)->query (base, query);
+      break;
+  }
+  return ret;
+}
+
 static gboolean
 gst_osx_audio_sink_stop (GstBaseSink * base)
 {
@@ -294,7 +306,7 @@ gst_osx_audio_sink_stop (GstBaseSink * base)
 }
 
 static GstCaps *
-gst_osx_audio_sink_getcaps (GstBaseSink * base)
+gst_osx_audio_sink_getcaps (GstBaseSink * base, GstCaps * filter)
 {
   GstOsxAudioSink *sink = GST_OSX_AUDIO_SINK (base);
   gchar *caps_string = NULL;
@@ -311,23 +323,22 @@ gst_osx_audio_sink_getcaps (GstBaseSink * base)
 }
 
 static gboolean
-gst_osx_audio_sink_acceptcaps (GstPad * pad, GstCaps * caps)
+gst_osx_audio_sink_acceptcaps (GstOsxAudioSink * sink, GstCaps * caps)
 {
-  GstOsxAudioSink *sink = GST_OSX_AUDIO_SINK (gst_pad_get_parent_element (pad));
-  GstOsxRingBuffer *osxbuf;
+  GstOsxAudioRingBuffer *osxbuf = NULL;
   GstCaps *pad_caps;
   GstStructure *st;
   gboolean ret = FALSE;
-  GstRingBufferSpec spec = { 0 };
+  GstAudioRingBufferSpec spec = { 0 };
   gchar *caps_string = NULL;
 
-  osxbuf = GST_OSX_RING_BUFFER (GST_BASE_AUDIO_SINK (sink)->ringbuffer);
+  osxbuf = GST_OSX_AUDIO_RING_BUFFER (GST_AUDIO_BASE_SINK (sink)->ringbuffer);
 
   caps_string = gst_caps_to_string (caps);
   GST_DEBUG_OBJECT (sink, "acceptcaps called with %s", caps_string);
   g_free (caps_string);
 
-  pad_caps = gst_pad_get_caps (pad);
+  pad_caps = gst_pad_query_caps (GST_BASE_SINK_PAD (sink), caps);
   if (pad_caps) {
     gboolean cret = gst_caps_can_intersect (pad_caps, caps);
     gst_caps_unref (pad_caps);
@@ -344,12 +355,12 @@ gst_osx_audio_sink_acceptcaps (GstPad * pad, GstCaps * caps)
   /* parse helper expects this set, so avoid nasty warning
    * will be set properly later on anyway  */
   spec.latency_time = GST_SECOND;
-  if (!gst_ring_buffer_parse_caps (&spec, caps))
+  if (!gst_audio_ring_buffer_parse_caps (&spec, caps))
     goto done;
 
   /* Make sure input is framed and can be payloaded */
   switch (spec.type) {
-    case GST_BUFTYPE_AC3:
+    case GST_AUDIO_RING_BUFFER_FORMAT_TYPE_AC3:
     {
       gboolean framed = FALSE;
 
@@ -360,7 +371,7 @@ gst_osx_audio_sink_acceptcaps (GstPad * pad, GstCaps * caps)
         goto done;
       break;
     }
-    case GST_BUFTYPE_DTS:
+    case GST_AUDIO_RING_BUFFER_FORMAT_TYPE_DTS:
     {
       gboolean parsed = FALSE;
 
@@ -377,12 +388,11 @@ gst_osx_audio_sink_acceptcaps (GstPad * pad, GstCaps * caps)
   ret = TRUE;
 
 done:
-  gst_object_unref (sink);
   return ret;
 }
 
 static GstBuffer *
-gst_osx_audio_sink_sink_payload (GstBaseAudioSink * sink, GstBuffer * buf)
+gst_osx_audio_sink_sink_payload (GstAudioBaseSink * sink, GstBuffer * buf)
 {
   GstOsxAudioSink *osxsink;
 
@@ -391,55 +401,64 @@ gst_osx_audio_sink_sink_payload (GstBaseAudioSink * sink, GstBuffer * buf)
   if (RINGBUFFER_IS_SPDIF (sink->ringbuffer->spec.type)) {
     gint framesize = gst_audio_iec61937_frame_size (&sink->ringbuffer->spec);
     GstBuffer *out;
+    GstMapInfo inmap, outmap;
+    gboolean res;
 
     if (framesize <= 0)
       return NULL;
 
     out = gst_buffer_new_and_alloc (framesize);
 
+    gst_buffer_map (buf, &inmap, GST_MAP_READ);
+    gst_buffer_map (out, &outmap, GST_MAP_WRITE);
+
     /* FIXME: the endianness needs to be queried and then set */
-    if (!gst_audio_iec61937_payload (GST_BUFFER_DATA (buf),
-            GST_BUFFER_SIZE (buf), GST_BUFFER_DATA (out),
-            GST_BUFFER_SIZE (out), &sink->ringbuffer->spec, G_BYTE_ORDER)) {
+    res = gst_audio_iec61937_payload (inmap.data, inmap.size,
+        outmap.data, outmap.size, &sink->ringbuffer->spec, G_BIG_ENDIAN);
+
+    gst_buffer_unmap (buf, &inmap);
+    gst_buffer_unmap (out, &outmap);
+
+    if (!res) {
       gst_buffer_unref (out);
       return NULL;
     }
 
-    gst_buffer_copy_metadata (out, buf, GST_BUFFER_COPY_ALL);
-
-    /* Fix endianness */
-    swab ((gchar *) GST_BUFFER_DATA (buf),
-        (gchar *) GST_BUFFER_DATA (buf), GST_BUFFER_SIZE (buf));
+    gst_buffer_copy_into (out, buf, GST_BUFFER_COPY_METADATA, 0, -1);
     return out;
+
   } else {
     return gst_buffer_ref (buf);
   }
 }
 
-static GstRingBuffer *
-gst_osx_audio_sink_create_ringbuffer (GstBaseAudioSink * sink)
+static GstAudioRingBuffer *
+gst_osx_audio_sink_create_ringbuffer (GstAudioBaseSink * sink)
 {
   GstOsxAudioSink *osxsink;
-  GstOsxRingBuffer *ringbuffer;
+  GstOsxAudioRingBuffer *ringbuffer;
 
   osxsink = GST_OSX_AUDIO_SINK (sink);
 
   if (!gst_osx_audio_sink_select_device (osxsink)) {
+    GST_ERROR_OBJECT (sink, "Could not select device");
     return NULL;
   }
 
-  GST_DEBUG ("Creating ringbuffer");
-  ringbuffer = g_object_new (GST_TYPE_OSX_RING_BUFFER, NULL);
-  GST_DEBUG ("osx sink %p element %p  ioproc %p", osxsink,
+  GST_DEBUG_OBJECT (sink, "Creating ringbuffer");
+  ringbuffer = g_object_new (GST_TYPE_OSX_AUDIO_RING_BUFFER, NULL);
+  GST_DEBUG_OBJECT (sink, "osx sink %p element %p  ioproc %p", osxsink,
       GST_OSX_AUDIO_ELEMENT_GET_INTERFACE (osxsink),
       (void *) gst_osx_audio_sink_io_proc);
 
   gst_osx_audio_sink_set_volume (osxsink);
 
-  ringbuffer->element = GST_OSX_AUDIO_ELEMENT_GET_INTERFACE (osxsink);
-  ringbuffer->device_id = osxsink->device_id;
+  ringbuffer->core_audio->element =
+      GST_OSX_AUDIO_ELEMENT_GET_INTERFACE (osxsink);
+  ringbuffer->core_audio->device_id = osxsink->device_id;
+  ringbuffer->core_audio->is_src = FALSE;
 
-  return GST_RING_BUFFER (ringbuffer);
+  return GST_AUDIO_RING_BUFFER (ringbuffer);
 }
 
 /* HALOutput AudioUnit will request fairly arbitrarily-sized chunks
@@ -447,7 +466,7 @@ gst_osx_audio_sink_create_ringbuffer (GstBaseAudioSink * sink)
  * the current ringbuffer segment we are, and only advance the segment
  * once we've read the whole thing */
 static OSStatus
-gst_osx_audio_sink_io_proc (GstOsxRingBuffer * buf,
+gst_osx_audio_sink_io_proc (GstOsxAudioRingBuffer * buf,
     AudioUnitRenderActionFlags * ioActionFlags,
     const AudioTimeStamp * inTimeStamp,
     UInt32 inBusNumber, UInt32 inNumberFrames, AudioBufferList * bufferList)
@@ -455,12 +474,12 @@ gst_osx_audio_sink_io_proc (GstOsxRingBuffer * buf,
   guint8 *readptr;
   gint readseg;
   gint len;
-  gint stream_idx = buf->stream_idx;
+  gint stream_idx = buf->core_audio->stream_idx;
   gint remaining = bufferList->mBuffers[stream_idx].mDataByteSize;
   gint offset = 0;
 
   while (remaining) {
-    if (!gst_ring_buffer_prepare_read (GST_RING_BUFFER (buf),
+    if (!gst_audio_ring_buffer_prepare_read (GST_AUDIO_RING_BUFFER (buf),
             &readseg, &readptr, &len))
       return 0;
 
@@ -476,12 +495,12 @@ gst_osx_audio_sink_io_proc (GstOsxRingBuffer * buf,
     offset += len;
     remaining -= len;
 
-    if ((gint) buf->segoffset == GST_RING_BUFFER (buf)->spec.segsize) {
+    if ((gint) buf->segoffset == GST_AUDIO_RING_BUFFER (buf)->spec.segsize) {
       /* clear written samples */
-      gst_ring_buffer_clear (GST_RING_BUFFER (buf), readseg);
+      gst_audio_ring_buffer_clear (GST_AUDIO_RING_BUFFER (buf), readseg);
 
       /* we wrote one segment */
-      gst_ring_buffer_advance (GST_RING_BUFFER (buf), 1);
+      gst_audio_ring_buffer_advance (GST_AUDIO_RING_BUFFER (buf), 1);
 
       buf->segoffset = 0;
     }
@@ -500,115 +519,106 @@ gst_osx_audio_sink_osxelement_init (gpointer g_iface, gpointer iface_data)
 static void
 gst_osx_audio_sink_set_volume (GstOsxAudioSink * sink)
 {
-  if (!sink->audiounit)
+  GstOsxAudioRingBuffer *osxbuf;
+
+  osxbuf = GST_OSX_AUDIO_RING_BUFFER (GST_AUDIO_BASE_SINK (sink)->ringbuffer);
+  if (!osxbuf)
     return;
 
-  AudioUnitSetParameter (sink->audiounit, kHALOutputParam_Volume,
-      kAudioUnitScope_Global, 0, (float) sink->volume, 0);
-}
-
-static inline void
-_dump_channel_layout (AudioChannelLayout * channel_layout)
-{
-  UInt32 i;
-
-  GST_DEBUG ("mChannelLayoutTag: 0x%lx",
-      (unsigned long) channel_layout->mChannelLayoutTag);
-  GST_DEBUG ("mChannelBitmap: 0x%lx",
-      (unsigned long) channel_layout->mChannelBitmap);
-  GST_DEBUG ("mNumberChannelDescriptions: %lu",
-      (unsigned long) channel_layout->mNumberChannelDescriptions);
-  for (i = 0; i < channel_layout->mNumberChannelDescriptions; i++) {
-    AudioChannelDescription *channel_desc =
-        &channel_layout->mChannelDescriptions[i];
-    GST_DEBUG ("  mChannelLabel: 0x%lx mChannelFlags: 0x%lx "
-        "mCoordinates[0]: %f mCoordinates[1]: %f "
-        "mCoordinates[2]: %f",
-        (unsigned long) channel_desc->mChannelLabel,
-        (unsigned long) channel_desc->mChannelFlags,
-        channel_desc->mCoordinates[0], channel_desc->mCoordinates[1],
-        channel_desc->mCoordinates[2]);
-  }
+  gst_core_audio_set_volume (osxbuf->core_audio, sink->volume);
 }
 
 static gboolean
 gst_osx_audio_sink_allowed_caps (GstOsxAudioSink * osxsink)
 {
-  gint i, max_channels = 0;
-  gboolean spdif_allowed, use_positions = FALSE;
+  gint i, channels;
+  gboolean spdif_allowed;
   AudioChannelLayout *layout;
   GstElementClass *element_class;
   GstPadTemplate *pad_template;
   GstCaps *caps, *in_caps;
-
-  GstAudioChannelPosition pos[9] = {
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID,
-    GST_AUDIO_CHANNEL_POSITION_INVALID
-  };
+  guint64 channel_mask = 0;
+  GstAudioChannelPosition *pos = osxsink->channel_positions;
 
   /* First collect info about the HW capabilites and preferences */
-  spdif_allowed = _audio_device_is_spdif_avail (osxsink->device_id);
-  layout = _audio_device_get_channel_layout (osxsink->device_id);
+  spdif_allowed =
+      gst_core_audio_audio_device_is_spdif_avail (osxsink->device_id);
+  layout = gst_core_audio_audio_device_get_channel_layout (osxsink->device_id);
 
   GST_DEBUG_OBJECT (osxsink, "Selected device ID: %u SPDIF allowed: %d",
       (unsigned) osxsink->device_id, spdif_allowed);
 
   if (layout) {
-    _dump_channel_layout (layout);
-    max_channels = layout->mNumberChannelDescriptions;
+    channels = MIN (layout->mNumberChannelDescriptions,
+        GST_OSX_AUDIO_MAX_CHANNEL);
   } else {
     GST_WARNING_OBJECT (osxsink, "This driver does not support "
         "kAudioDevicePropertyPreferredChannelLayout.");
-    max_channels = 2;
+    channels = 2;
   }
 
-  if (max_channels > 2) {
-    max_channels = MIN (max_channels, 9);
-    use_positions = TRUE;
-    for (i = 0; i < max_channels; i++) {
-      switch (layout->mChannelDescriptions[i].mChannelLabel) {
-        case kAudioChannelLabel_Left:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_FRONT_LEFT;
-          break;
-        case kAudioChannelLabel_Right:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_FRONT_RIGHT;
-          break;
-        case kAudioChannelLabel_Center:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_FRONT_CENTER;
-          break;
-        case kAudioChannelLabel_LFEScreen:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_LFE;
-          break;
-        case kAudioChannelLabel_LeftSurround:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_REAR_LEFT;
-          break;
-        case kAudioChannelLabel_RightSurround:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_REAR_RIGHT;
-          break;
-        case kAudioChannelLabel_RearSurroundLeft:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_SIDE_LEFT;
-          break;
-        case kAudioChannelLabel_RearSurroundRight:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_SIDE_RIGHT;
-          break;
-        case kAudioChannelLabel_CenterSurround:
-          pos[i] = GST_AUDIO_CHANNEL_POSITION_REAR_CENTER;
-          break;
-        default:
-          GST_WARNING_OBJECT (osxsink, "unrecognized channel: %d",
-              (int) layout->mChannelDescriptions[i].mChannelLabel);
-          use_positions = FALSE;
-          max_channels = 2;
-          break;
+  switch (channels) {
+    case 0:
+      pos[0] = GST_AUDIO_CHANNEL_POSITION_NONE;
+      break;
+    case 1:
+      pos[0] = GST_AUDIO_CHANNEL_POSITION_MONO;
+      break;
+    case 2:
+      pos[0] = GST_AUDIO_CHANNEL_POSITION_FRONT_LEFT;
+      pos[1] = GST_AUDIO_CHANNEL_POSITION_FRONT_RIGHT;
+      channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (FRONT_LEFT);
+      channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (FRONT_RIGHT);
+      break;
+    default:
+      channels = MIN (layout->mNumberChannelDescriptions,
+          GST_OSX_AUDIO_MAX_CHANNEL);
+      for (i = 0; i < channels; i++) {
+        switch (layout->mChannelDescriptions[i].mChannelLabel) {
+          case kAudioChannelLabel_Left:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_FRONT_LEFT;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (FRONT_LEFT);
+            break;
+          case kAudioChannelLabel_Right:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_FRONT_RIGHT;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (FRONT_RIGHT);
+            break;
+          case kAudioChannelLabel_Center:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_FRONT_CENTER;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (FRONT_CENTER);
+            break;
+          case kAudioChannelLabel_LFEScreen:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_LFE1;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (LFE1);
+            break;
+          case kAudioChannelLabel_LeftSurround:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_REAR_LEFT;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (REAR_LEFT);
+            break;
+          case kAudioChannelLabel_RightSurround:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_REAR_RIGHT;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (REAR_RIGHT);
+            break;
+          case kAudioChannelLabel_RearSurroundLeft:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_SIDE_LEFT;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (SIDE_LEFT);
+            break;
+          case kAudioChannelLabel_RearSurroundRight:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_SIDE_RIGHT;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (SIDE_RIGHT);
+            break;
+          case kAudioChannelLabel_CenterSurround:
+            pos[i] = GST_AUDIO_CHANNEL_POSITION_REAR_CENTER;
+            channel_mask |= GST_AUDIO_CHANNEL_POSITION_MASK (REAR_CENTER);
+            break;
+          default:
+            GST_WARNING_OBJECT (osxsink, "unrecognized channel: %d",
+                (int) layout->mChannelDescriptions[i].mChannelLabel);
+            channel_mask = 0;
+            channels = 2;
+            break;
+        }
       }
-    }
   }
   g_free (layout);
 
@@ -629,19 +639,12 @@ gst_osx_audio_sink_allowed_caps (GstOsxAudioSink * osxsink)
       if (spdif_allowed) {
         gst_caps_append_structure (caps, gst_structure_copy (in_s));
       }
-    } else {
-      if (max_channels > 2 && use_positions) {
-        out_s = gst_structure_copy (in_s);
-        gst_structure_remove_field (out_s, "channels");
-        gst_structure_set (out_s, "channels", G_TYPE_INT, max_channels, NULL);
-        gst_audio_set_channel_positions (out_s, pos);
-        gst_caps_append_structure (caps, out_s);
-      }
-      out_s = gst_structure_copy (in_s);
-      gst_structure_remove_field (out_s, "channels");
-      gst_structure_set (out_s, "channels", GST_TYPE_INT_RANGE, 1, 2, NULL);
-      gst_caps_append_structure (caps, out_s);
     }
+    out_s = gst_structure_copy (in_s);
+    gst_structure_remove_fields (out_s, "channels", "channel-mask", NULL);
+    gst_structure_set (out_s, "channels", G_TYPE_INT, channels,
+        "channel-mask", GST_TYPE_BITMASK, channel_mask, NULL);
+    gst_caps_append_structure (caps, out_s);
   }
 
   if (osxsink->cached_caps) {
@@ -649,6 +652,7 @@ gst_osx_audio_sink_allowed_caps (GstOsxAudioSink * osxsink)
   }
 
   osxsink->cached_caps = caps;
+  osxsink->channels = channels;
 
   return TRUE;
 }
@@ -656,71 +660,11 @@ gst_osx_audio_sink_allowed_caps (GstOsxAudioSink * osxsink)
 static gboolean
 gst_osx_audio_sink_select_device (GstOsxAudioSink * osxsink)
 {
-  AudioDeviceID *devices = NULL;
-  AudioDeviceID default_device_id = 0;
-  AudioChannelLayout *channel_layout;
-  gint i, ndevices = 0;
   gboolean res = FALSE;
 
-  devices = _audio_system_get_devices (&ndevices);
-
-  if (ndevices < 1) {
-    GST_ERROR_OBJECT (osxsink, "no audio output devices found");
-    goto done;
-  }
-
-  GST_DEBUG_OBJECT (osxsink, "found %d audio device(s)", ndevices);
-
-  for (i = 0; i < ndevices; i++) {
-    gchar *device_name;
-
-    if ((device_name = _audio_device_get_name (devices[i]))) {
-      if (!_audio_device_has_output (devices[i])) {
-        GST_DEBUG_OBJECT (osxsink, "Input Device ID: %u Name: %s",
-            (unsigned) devices[i], device_name);
-      } else {
-        GST_DEBUG_OBJECT (osxsink, "Output Device ID: %u Name: %s",
-            (unsigned) devices[i], device_name);
-
-        channel_layout = _audio_device_get_channel_layout (devices[i]);
-        if (channel_layout) {
-          _dump_channel_layout (channel_layout);
-          g_free (channel_layout);
-        }
-      }
-
-      g_free (device_name);
-    }
-  }
-
-  /* Find the ID of the default output device */
-  default_device_id = _audio_system_get_default_output ();
-
-  /* Here we decide if selected device is valid or autoselect
-   * the default one when required */
-  if (osxsink->device_id == kAudioDeviceUnknown) {
-    if (default_device_id != kAudioDeviceUnknown) {
-      osxsink->device_id = default_device_id;
-      res = TRUE;
-    }
-  } else {
-    for (i = 0; i < ndevices; i++) {
-      if (osxsink->device_id == devices[i]) {
-        res = TRUE;
-      }
-    }
-
-    if (res && !_audio_device_is_alive (osxsink->device_id)) {
-      GST_ERROR_OBJECT (osxsink, "Requested device not usable");
-      res = FALSE;
-      goto done;
-    }
-  }
-
+  if (!gst_core_audio_select_device (&osxsink->device_id))
+    return FALSE;
   res = gst_osx_audio_sink_allowed_caps (osxsink);
 
-done:
-  g_free (devices);
-
   return res;
 }
