@@ -39,8 +39,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  * The development of this code was made possible due to the involvement of
  * Pioneers of the Inevitable, the creators of the Songbird Music player
@@ -57,14 +57,6 @@
 
 G_BEGIN_DECLS
 
-#define GST_OSX_AUDIO_SINK_CAPS "audio/x-raw, " \
-        "format = (string) " GST_AUDIO_FORMATS_ALL ", " \
-        "layout = (string) interleaved, " \
-        "rate = (int) [1, MAX], " \
-        "channels = (int) [1, 9];" \
-        "audio/x-ac3, framed = (boolean) true;" \
-        "audio/x-dts, framed = (boolean) true"
-
 #define GST_TYPE_OSX_AUDIO_SINK \
   (gst_osx_audio_sink_get_type())
 #define GST_OSX_AUDIO_SINK(obj) \
@@ -74,6 +66,8 @@ G_BEGIN_DECLS
 #define GST_IS_OSX_AUDIO_SINK(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_OSX_AUDIO_SINK))
 
+#define GST_OSX_AUDIO_MAX_CHANNEL (9)
+
 typedef struct _GstOsxAudioSink GstOsxAudioSink;
 typedef struct _GstOsxAudioSinkClass GstOsxAudioSinkClass;
 
@@ -82,16 +76,13 @@ struct _GstOsxAudioSink
   GstAudioBaseSink sink;
 
   AudioDeviceID device_id;
-  char *unique_id;
 
   AudioUnit audiounit;
   double volume;
+  GstCaps *cached_caps;
 
   guint channels;
-
-#if !TARGET_OS_OSX
-  gboolean configure_session;
-#endif
+  GstAudioChannelPosition channel_positions[GST_OSX_AUDIO_MAX_CHANNEL];
 };
 
 struct _GstOsxAudioSinkClass
@@ -101,8 +92,6 @@ struct _GstOsxAudioSinkClass
 
 GType gst_osx_audio_sink_get_type (void);
 
-GST_ELEMENT_REGISTER_DECLARE (osxaudiosink);
-
 G_END_DECLS
 
 #endif /* __GST_OSXAUDIOSINK_H__ */
