@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  *
  */
 
@@ -27,7 +27,6 @@
 #endif
 
 #include <gst/gst.h>
-#include <gst/audio/audio-channels.h>
 #ifdef HAVE_IOS
   #include <CoreAudio/CoreAudioTypes.h>
   #define AudioDeviceID gint
@@ -35,7 +34,7 @@
 #else
   #include <CoreAudio/CoreAudio.h>
   #include <AudioToolbox/AudioToolbox.h>
-  #if MAC_OS_X_VERSION_MIN_REQUIRED < 1060
+  #if MAC_OS_X_VERSION_MIN_REQUIRED <= MAC_OS_X_VERSION_10_5
     #include <CoreServices/CoreServices.h>
     #define AudioComponentFindNext FindNextComponent
     #define AudioComponentInstanceNew OpenAComponent
@@ -45,7 +44,6 @@
   #endif
 #endif
 #include <AudioUnit/AudioUnit.h>
-#include <mach/mach_time.h>
 #include "gstosxaudioelement.h"
 
 
@@ -64,23 +62,14 @@ G_BEGIN_DECLS
 #define GST_IS_CORE_AUDIO_CLASS(klass) \
   (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_CORE_AUDIO))
 
-#define GST_OSX_AUDIO_MAX_CHANNEL (64)
-
 #define CORE_AUDIO_FORMAT_IS_SPDIF(f) ((f).mFormat.mFormatID == 'IAC3' || (f).mFormat.mFormatID == 'iac3' || (f).mFormat.mFormatID == kAudioFormat60958AC3 || (f).mFormat.mFormatID == kAudioFormatAC3)
 
 #define CORE_AUDIO_FORMAT "FormatID: %" GST_FOURCC_FORMAT " rate: %f flags: 0x%x BytesPerPacket: %u FramesPerPacket: %u BytesPerFrame: %u ChannelsPerFrame: %u BitsPerChannel: %u"
-#define CORE_AUDIO_FORMAT_ARGS(f) GST_FOURCC_ARGS((unsigned int)(f).mFormatID),(f).mSampleRate,(unsigned int)(f).mFormatFlags,(unsigned int)(f).mBytesPerPacket,(unsigned int)(f).mFramesPerPacket,(unsigned int)(f).mBytesPerFrame,(unsigned int)(f).mChannelsPerFrame,(unsigned int)(f).mBitsPerChannel
-
-#define CORE_AUDIO_INNER_SCOPE(core_audio) ((core_audio)->is_src ? kAudioUnitScope_Output : kAudioUnitScope_Input)
-#define CORE_AUDIO_OUTER_SCOPE(core_audio) ((core_audio)->is_src ? kAudioUnitScope_Input : kAudioUnitScope_Output)
-#define CORE_AUDIO_ELEMENT(core_audio) ((core_audio)->is_src ? 1 : 0)
+#define CORE_AUDIO_FORMAT_ARGS(f) GST_FOURCC_ARGS((f).mFormatID),(f).mSampleRate,(unsigned)(f).mFormatFlags,(unsigned)(f).mBytesPerPacket,(unsigned)(f).mFramesPerPacket,(unsigned)(f).mBytesPerFrame,(unsigned)(f).mChannelsPerFrame,(unsigned)(f).mBitsPerChannel
 
 typedef struct _GstCoreAudio GstCoreAudio;
 typedef struct _GstCoreAudioClass GstCoreAudioClass;
 
-#define CORE_AUDIO_TIMING_LOCK(core_audio) (g_mutex_lock(&(core_audio->timing_lock)))
-#define CORE_AUDIO_TIMING_UNLOCK(core_audio) (g_mutex_unlock(&(core_audio->timing_lock)))
-
 struct _GstCoreAudio
 {
   GObject object;
@@ -91,17 +80,13 @@ struct _GstCoreAudio
   gboolean is_src;
   gboolean is_passthrough;
   AudioDeviceID device_id;
-  char *unique_id;
-  gboolean is_default;
-  gboolean cached_caps_valid; /* thread-safe flag */
-  GstCaps *cached_caps;
+  AudioStreamBasicDescription stream_format;
   gint stream_idx;
   gboolean io_proc_active;
-  gboolean io_proc_dropping;
+  gboolean io_proc_needs_deactivation;
 
   /* For LPCM in/out */
   AudioUnit audiounit;
-  UInt32 recBufferSize; /* AudioUnitRender clobbers mDataByteSize */
   AudioBufferList *recBufferList;
 
 #ifndef HAVE_IOS
@@ -110,20 +95,9 @@ struct _GstCoreAudio
   gboolean disabled_mixing;
   AudioStreamID stream_id;
   gboolean revert_format;
-  AudioStreamBasicDescription original_format, stream_format;
+  AudioStreamBasicDescription original_format;
   AudioDeviceIOProcID procID;
 #endif
-
-  mach_timebase_info_data_t timebase;
-  GMutex timing_lock;
-  uint64_t anchor_hosttime_ns;
-  uint32_t anchor_pend_samples;
-  float rate_scalar;
-
-#ifdef HAVE_IOS
-  gdouble first_sample_time;
-  gboolean configure_session;
-#endif
 };
 
 struct _GstCoreAudioClass
@@ -135,6 +109,8 @@ GType gst_core_audio_get_type                                (void);
 
 void gst_core_audio_init_debug (void);
 
+GstCoreAudio * gst_core_audio_new                            (GstObject *osxbuf);
+
 gboolean gst_core_audio_open                                 (GstCoreAudio *core_audio);
 
 gboolean gst_core_audio_close                                (GstCoreAudio *core_audio);
@@ -142,10 +118,9 @@ gboolean gst_core_audio_close                                (GstCoreAudio *core
 gboolean gst_core_audio_initialize                           (GstCoreAudio *core_audio,
                                                               AudioStreamBasicDescription format,
                                                               GstCaps *caps,
-                                                              guint32 frames_per_packet,
                                                               gboolean is_passthrough);
 
-void gst_core_audio_uninitialize                             (GstCoreAudio *core_audio);
+void gst_core_audio_unitialize                               (GstCoreAudio *core_audio);
 
 gboolean gst_core_audio_start_processing                     (GstCoreAudio *core_audio);
 
@@ -158,28 +133,18 @@ gboolean gst_core_audio_get_samples_and_latency              (GstCoreAudio * cor
                                                               guint *samples,
                                                               gdouble *latency);
 
-void gst_core_audio_update_timing                            (GstCoreAudio * core_audio,
-                                                              const AudioTimeStamp * inTimeStamp,
-                                                              unsigned int inNumberFrames);
-
 void  gst_core_audio_set_volume                              (GstCoreAudio *core_audio,
                                                               gfloat volume);
 
 gboolean gst_core_audio_audio_device_is_spdif_avail          (AudioDeviceID device_id);
 
 
-gboolean gst_core_audio_select_device                        (GstCoreAudio * core_audio);
+gboolean gst_core_audio_select_device                        (AudioDeviceID *device_id);
 
-GstCaps *
-gst_core_audio_probe_caps (GstCoreAudio * core_audio, GstCaps * in_caps);
+gboolean gst_core_audio_select_source_device                        (AudioDeviceID *device_id);
 
-AudioChannelLayout *
-gst_core_audio_get_channel_layout (GstCoreAudio * core_audio, gboolean outer);
+AudioChannelLayout * gst_core_audio_audio_device_get_channel_layout (AudioDeviceID device_id);
 
-gboolean gst_core_audio_parse_channel_layout (AudioChannelLayout * layout,
-    AudioDeviceID device_id, guint * channels, guint64 * channel_mask, GstAudioChannelPosition * pos);
-GstCaps * gst_core_audio_asbd_to_caps (AudioStreamBasicDescription * asbd, AudioDeviceID device_id,
-    AudioChannelLayout * layout);
 
 G_END_DECLS
 
