@@ -14,39 +14,31 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 /**
  * SECTION:element-ximagesrc
- * @title: ximagesrc
  *
- * This element captures your X Display and creates raw RGB video. It uses
+ * This element captures your X Display and creates raw RGB video.  It uses
  * the XDamage extension if available to only capture areas of the screen that
- * have changed since the last frame. It uses the XFixes extension if
- * available to also capture your mouse pointer. It supports handling of
- * mouse and keyboard events. By default it will fixate to 25 frames per second.
- * 
- * Applications are expected to call `XinitThreads()` before any other threads
- * are started. For use in gst-launch-1.0 or other GStreamer command line 
- * applications it is also possible to set the GST_XINITTHREADS=1 environment 
- * variable so that `XInitThreads()` gets called when the plugin is loaded. This 
- * may be too late in other use case scenarios though, so applications should 
- * not rely on that.
+ * have changed since the last frame.  It uses the XFixes extension if
+ * available to also capture your mouse pointer.  By default it will fixate to
+ * 25 frames per second.
  *
- * ## Example pipelines
+ * <refsect2>
+ * <title>Example pipelines</title>
  * |[
  * gst-launch-1.0 ximagesrc ! video/x-raw,framerate=5/1 ! videoconvert ! theoraenc ! oggmux ! filesink location=desktop.ogg
  * ]| Encodes your X display to an Ogg theora video at 5 frames per second.
- *
+ * </refsect2>
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 #include "gstximagesrc.h"
-#include "gst-ximage-navigation.h"
 
 #include <string.h>
 #include <stdlib.h>
@@ -55,7 +47,7 @@
 #include <X11/Xutil.h>
 
 #include <gst/gst.h>
-#include <glib/gi18n-lib.h>
+#include <gst/gst-i18n-plugin.h>
 #include <gst/video/video.h>
 
 #include "gst/glib-compat-private.h"
@@ -63,14 +55,6 @@
 GST_DEBUG_CATEGORY_STATIC (gst_debug_ximage_src);
 #define GST_CAT_DEFAULT gst_debug_ximage_src
 
-#define MOUSE_SCROLL_UP_BUTTON 4
-#define MOUSE_SCROLL_DOWN_BUTTON 5
-
-#define KEYCODE_CTRL 0x25
-#define KEYCODE_SHIFT 0x32
-#define KEYCODE_ALT 0x40
-#define KEYCODE_META 0x85
-
 static GstStaticPadTemplate t =
 GST_STATIC_PAD_TEMPLATE ("src", GST_PAD_SRC, GST_PAD_ALWAYS,
     GST_STATIC_CAPS ("video/x-raw, "
@@ -82,6 +66,7 @@ enum
 {
   PROP_0,
   PROP_DISPLAY_NAME,
+  PROP_SCREEN_NUM,
   PROP_SHOW_POINTER,
   PROP_USE_DAMAGE,
   PROP_STARTX,
@@ -91,7 +76,6 @@ enum
   PROP_REMOTE,
   PROP_XID,
   PROP_XNAME,
-  PROP_ENABLE_NAVIGATION_EVENTS
 };
 
 #define gst_ximage_src_parent_class parent_class
@@ -101,12 +85,10 @@ static GstCaps *gst_ximage_src_fixate (GstBaseSrc * bsrc, GstCaps * caps);
 static void gst_ximage_src_clear_bufpool (GstXImageSrc * ximagesrc);
 
 /* Called when a buffer is returned from the pipeline */
-static gboolean
+static void
 gst_ximage_src_return_buf (GstXImageSrc * ximagesrc, GstBuffer * ximage)
 {
   GstMetaXImage *meta = GST_META_XIMAGE_GET (ximage);
-  /* True will make dispose free the buffer, while false will keep it */
-  gboolean ret = TRUE;
 
   /* If our geometry changed we can't reuse that image. */
   if ((meta->width != ximagesrc->width) || (meta->height != ximagesrc->height)) {
@@ -125,10 +107,7 @@ gst_ximage_src_return_buf (GstXImageSrc * ximagesrc, GstBuffer * ximage)
     GST_BUFFER_FLAGS (GST_BUFFER (ximage)) = 0; /* clear out any flags from the previous use */
     ximagesrc->buffer_pool = g_slist_prepend (ximagesrc->buffer_pool, ximage);
     g_mutex_unlock (&ximagesrc->pool_lock);
-    ret = FALSE;
   }
-
-  return ret;
 }
 
 static Window
@@ -185,9 +164,6 @@ gst_ximage_src_open_display (GstXImageSrc * s, const gchar * name)
     int status;
     XWindowAttributes attrs;
     Window window;
-    int x, y;
-    Window child;
-    Bool coord_translated;
 
     if (s->xid != 0) {
       status = XGetWindowAttributes (s->xcontext->disp, s->xid, &attrs);
@@ -224,19 +200,8 @@ gst_ximage_src_open_display (GstXImageSrc * s, const gchar * name)
     g_assert (s->xwindow != 0);
     s->width = attrs.width;
     s->height = attrs.height;
-
-    coord_translated = XTranslateCoordinates (s->xcontext->disp, s->xwindow,
-        s->xcontext->root, 0, 0, &x, &y, &child);
-    if (coord_translated) {
-      s->x = x;
-      s->y = y;
-    } else {
-      s->x = 0;
-      s->y = 0;
-    }
-
-    GST_INFO_OBJECT (s, "Using default window size of %dx%d at location %d,%d",
-        s->width, s->height, s->x, s->y);
+    GST_INFO_OBJECT (s, "Using default window size of %dx%d",
+        s->width, s->height);
   }
 use_root_window:
 
@@ -381,44 +346,14 @@ gst_ximage_src_unlock (GstBaseSrc * basesrc)
 static gboolean
 gst_ximage_src_recalc (GstXImageSrc * src)
 {
-  XWindowAttributes attrs;
-  gboolean has_changed = FALSE;
+  if (!src->xcontext)
+    return FALSE;
 
-  g_assert (src->xwindow != 0 && src->xcontext);
-
-  if (XGetWindowAttributes (src->xcontext->disp, src->xwindow, &attrs)) {
-    if (src->xwin_width != attrs.width) {
-      src->xwin_width = attrs.width;
-      has_changed = TRUE;
-    }
-    if (src->xwin_height != attrs.height) {
-      src->xwin_height = attrs.height;
-      has_changed = TRUE;
-    }
-  }
-
-  return has_changed;
+  /* Maybe later we can check the display hasn't changed size */
+  /* We could use XQueryPointer to get only the current window. */
+  return TRUE;
 }
 
-#ifdef HAVE_XFIXES
-static gboolean
-gst_ximage_is_pointer_in_region (GstXImageSrc * src)
-{
-  Window window_returned;
-  int root_x, root_y;
-  int win_x, win_y;
-  unsigned int mask_return;
-  Bool on_window;
-
-  on_window = XQueryPointer (src->xcontext->disp, src->xwindow,
-      &window_returned, &window_returned, &root_x, &root_y, &win_x, &win_y,
-      &mask_return);
-
-  return (on_window && (win_x >= src->startx) && (win_y >= src->starty) &&
-      (win_x < src->endx) && (win_y < src->endy));
-}
-#endif
-
 #ifdef HAVE_XFIXES
 static void
 composite_pixel (GstXContext * xcontext, guchar * dest, guchar * src)
@@ -525,15 +460,13 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
 
     meta = GST_META_XIMAGE_GET (ximage);
 
+    if ((meta->width != ximagesrc->width) ||
+        (meta->height != ximagesrc->height)) {
+      gst_ximage_buffer_free (ximage);
+    }
+
     ximagesrc->buffer_pool = g_slist_delete_link (ximagesrc->buffer_pool,
         ximagesrc->buffer_pool);
-
-    if ((meta->width == ximagesrc->width) &&
-        (meta->height == ximagesrc->height))
-      break;
-
-    gst_ximage_buffer_free (ximage);
-    ximage = NULL;
   }
   g_mutex_unlock (&ximagesrc->pool_lock);
 
@@ -564,7 +497,6 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
   if (ximagesrc->have_xdamage && ximagesrc->use_damage &&
       ximagesrc->last_ximage != NULL) {
     XEvent ev;
-    gboolean have_damage = FALSE;
 
     /* have_frame is TRUE when either the entire screen has been
      * grabbed or when the last image has been copied */
@@ -573,90 +505,83 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
     GST_DEBUG_OBJECT (ximagesrc, "Retrieving screen using XDamage");
 
     do {
-      XDamageNotifyEvent *damage_ev = (XDamageNotifyEvent *) (&ev);
+      XNextEvent (ximagesrc->xcontext->disp, &ev);
 
-      if (XCheckTypedEvent (ximagesrc->xcontext->disp,
-              ximagesrc->damage_event_base + XDamageNotify, &ev) &&
-          damage_ev->level == XDamageReportNonEmpty) {
+      if (ev.type == ximagesrc->damage_event_base + XDamageNotify) {
+        XserverRegion parts;
+        XRectangle *rects;
+        int nrects;
 
+        parts = XFixesCreateRegion (ximagesrc->xcontext->disp, 0, 0);
         XDamageSubtract (ximagesrc->xcontext->disp, ximagesrc->damage, None,
-            ximagesrc->damage_region);
-        have_damage = TRUE;
-      }
-    } while (XPending (ximagesrc->xcontext->disp));
-
-    if (have_damage) {
-      XRectangle *rects;
-      int nrects;
-
-      /* Now copy out all of the damaged rectangles. */
-      rects =
-          XFixesFetchRegion (ximagesrc->xcontext->disp,
-          ximagesrc->damage_region, &nrects);
-      if (rects != NULL) {
-        int i;
-
-        if (!have_frame) {
-          GST_LOG_OBJECT (ximagesrc,
-              "Copying from last frame ximage->size: %" G_GSIZE_FORMAT,
-              gst_buffer_get_size (ximage));
-          copy_buffer (ximage, ximagesrc->last_ximage);
-          have_frame = TRUE;
-        }
-        for (i = 0; i < nrects; i++) {
-          GST_LOG_OBJECT (ximagesrc,
-              "Damaged sub-region @ %d,%d size %dx%d reported",
-              rects[i].x, rects[i].y, rects[i].width, rects[i].height);
-
-          /* if we only want a small area, clip this damage region to
-           * area we want */
-          if (ximagesrc->endx > ximagesrc->startx &&
-              ximagesrc->endy > ximagesrc->starty) {
-            /* see if damage area intersects */
-            if (rects[i].x + rects[i].width - 1 < ximagesrc->startx ||
-                rects[i].x > ximagesrc->endx) {
-              /* trivial reject */
-            } else if (rects[i].y + rects[i].height - 1 < ximagesrc->starty ||
-                rects[i].y > ximagesrc->endy) {
-              /* trivial reject */
-            } else {
-              /* find intersect region */
-              int startx, starty, width, height;
-
-              startx = (rects[i].x < ximagesrc->startx) ? ximagesrc->startx :
-                  rects[i].x;
-              starty = (rects[i].y < ximagesrc->starty) ? ximagesrc->starty :
-                  rects[i].y;
-              width = (rects[i].x + rects[i].width - 1 < ximagesrc->endx) ?
-                  rects[i].x + rects[i].width - startx :
-                  ximagesrc->endx - startx + 1;
-              height = (rects[i].y + rects[i].height - 1 < ximagesrc->endy) ?
-                  rects[i].y + rects[i].height - starty : ximagesrc->endy -
-                  starty + 1;
-
-              GST_LOG_OBJECT (ximagesrc,
-                  "Retrieving damaged sub-region @ %d,%d size %dx%d as intersect region",
-                  startx, starty, width, height);
-              XGetSubImage (ximagesrc->xcontext->disp, ximagesrc->xwindow,
-                  startx, starty, width, height, AllPlanes, ZPixmap,
-                  meta->ximage, startx - ximagesrc->startx,
-                  starty - ximagesrc->starty);
-            }
-          } else {
+            parts);
+        /* Now copy out all of the damaged rectangles. */
+        rects = XFixesFetchRegion (ximagesrc->xcontext->disp, parts, &nrects);
+        if (rects != NULL) {
+          int i;
 
+          if (!have_frame) {
             GST_LOG_OBJECT (ximagesrc,
-                "Retrieving damaged sub-region @ %d,%d size %dx%d",
+                "Copying from last frame ximage->size: %" G_GSIZE_FORMAT,
+                gst_buffer_get_size (ximage));
+            copy_buffer (ximage, ximagesrc->last_ximage);
+            have_frame = TRUE;
+          }
+          for (i = 0; i < nrects; i++) {
+            GST_LOG_OBJECT (ximagesrc,
+                "Damaged sub-region @ %d,%d size %dx%d reported",
                 rects[i].x, rects[i].y, rects[i].width, rects[i].height);
 
-            XGetSubImage (ximagesrc->xcontext->disp, ximagesrc->xwindow,
-                rects[i].x, rects[i].y,
-                rects[i].width, rects[i].height,
-                AllPlanes, ZPixmap, meta->ximage, rects[i].x, rects[i].y);
+            /* if we only want a small area, clip this damage region to
+             * area we want */
+            if (ximagesrc->endx > ximagesrc->startx &&
+                ximagesrc->endy > ximagesrc->starty) {
+              /* see if damage area intersects */
+              if (rects[i].x + rects[i].width - 1 < ximagesrc->startx ||
+                  rects[i].x > ximagesrc->endx) {
+                /* trivial reject */
+              } else if (rects[i].y + rects[i].height - 1 < ximagesrc->starty ||
+                  rects[i].y > ximagesrc->endy) {
+                /* trivial reject */
+              } else {
+                /* find intersect region */
+                int startx, starty, width, height;
+
+                startx = (rects[i].x < ximagesrc->startx) ? ximagesrc->startx :
+                    rects[i].x;
+                starty = (rects[i].y < ximagesrc->starty) ? ximagesrc->starty :
+                    rects[i].y;
+                width = (rects[i].x + rects[i].width - 1 < ximagesrc->endx) ?
+                    rects[i].x + rects[i].width - startx :
+                    ximagesrc->endx - startx + 1;
+                height = (rects[i].y + rects[i].height - 1 < ximagesrc->endy) ?
+                    rects[i].y + rects[i].height - starty : ximagesrc->endy -
+                    starty + 1;
+
+                GST_LOG_OBJECT (ximagesrc,
+                    "Retrieving damaged sub-region @ %d,%d size %dx%d as intersect region",
+                    startx, starty, width, height);
+                XGetSubImage (ximagesrc->xcontext->disp, ximagesrc->xwindow,
+                    startx, starty, width, height, AllPlanes, ZPixmap,
+                    meta->ximage, startx - ximagesrc->startx,
+                    starty - ximagesrc->starty);
+              }
+            } else {
+
+              GST_LOG_OBJECT (ximagesrc,
+                  "Retrieving damaged sub-region @ %d,%d size %dx%d",
+                  rects[i].x, rects[i].y, rects[i].width, rects[i].height);
+
+              XGetSubImage (ximagesrc->xcontext->disp, ximagesrc->xwindow,
+                  rects[i].x, rects[i].y,
+                  rects[i].width, rects[i].height,
+                  AllPlanes, ZPixmap, meta->ximage, rects[i].x, rects[i].y);
+            }
           }
+          free (rects);
         }
-        XFree (rects);
       }
-    }
+    } while (XPending (ximagesrc->xcontext->disp));
     if (!have_frame) {
       GST_LOG_OBJECT (ximagesrc,
           "Copying from last frame ximage->size: %" G_GSIZE_FORMAT,
@@ -669,10 +594,8 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
     if (ximagesrc->cursor_image) {
       gint x, y, width, height;
 
-      x = ximagesrc->cursor_image->x - ximagesrc->cursor_image->xhot -
-          ximagesrc->x;
-      y = ximagesrc->cursor_image->y - ximagesrc->cursor_image->yhot -
-          ximagesrc->y;
+      x = ximagesrc->cursor_image->x - ximagesrc->cursor_image->xhot;
+      y = ximagesrc->cursor_image->y - ximagesrc->cursor_image->yhot;
       width = ximagesrc->cursor_image->width;
       height = ximagesrc->cursor_image->height;
 
@@ -754,8 +677,7 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
 #endif
 
 #ifdef HAVE_XFIXES
-  if (ximagesrc->show_pointer && ximagesrc->have_xfixes
-      && gst_ximage_is_pointer_in_region (ximagesrc)) {
+  if (ximagesrc->show_pointer && ximagesrc->have_xfixes) {
 
     GST_DEBUG_OBJECT (ximagesrc, "Using XFixes to draw cursor");
     /* get cursor */
@@ -767,36 +689,37 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
       int startx, starty, iwidth, iheight;
       gboolean cursor_in_image = TRUE;
 
-      cx = ximagesrc->cursor_image->x - ximagesrc->cursor_image->xhot -
-          ximagesrc->x;
-      cy = ximagesrc->cursor_image->y - ximagesrc->cursor_image->yhot -
-          ximagesrc->y;
+      cx = ximagesrc->cursor_image->x - ximagesrc->cursor_image->xhot;
+      if (cx < 0)
+        cx = 0;
+      cy = ximagesrc->cursor_image->y - ximagesrc->cursor_image->yhot;
+      if (cy < 0)
+        cy = 0;
       count = ximagesrc->cursor_image->width * ximagesrc->cursor_image->height;
 
       /* only get where cursor last was, if it is in our range */
       if (ximagesrc->endx > ximagesrc->startx &&
           ximagesrc->endy > ximagesrc->starty) {
         /* check bounds */
-        if (cx + ximagesrc->cursor_image->width < (int) ximagesrc->startx ||
-            cx > (int) ximagesrc->endx) {
+        if (cx + ximagesrc->cursor_image->width < ximagesrc->startx ||
+            cx > ximagesrc->endx) {
           /* trivial reject */
           cursor_in_image = FALSE;
-        } else if (cy + ximagesrc->cursor_image->height <
-            (int) ximagesrc->starty || cy > (int) ximagesrc->endy) {
+        } else if (cy + ximagesrc->cursor_image->height < ximagesrc->starty ||
+            cy > ximagesrc->endy) {
           /* trivial reject */
           cursor_in_image = FALSE;
         } else {
           /* find intersect region */
 
-          startx = (cx < (int) ximagesrc->startx) ? ximagesrc->startx : cx;
-          starty = (cy < (int) ximagesrc->starty) ? ximagesrc->starty : cy;
+          startx = (cx < ximagesrc->startx) ? ximagesrc->startx : cx;
+          starty = (cy < ximagesrc->starty) ? ximagesrc->starty : cy;
           iwidth = (cx + ximagesrc->cursor_image->width < ximagesrc->endx) ?
               cx + ximagesrc->cursor_image->width - startx :
               ximagesrc->endx - startx;
-          iheight =
-              (cy + ximagesrc->cursor_image->height <
-              ximagesrc->endy) ? cy + ximagesrc->cursor_image->height -
-              starty : ximagesrc->endy - starty;
+          iheight = (cy + ximagesrc->cursor_image->height < ximagesrc->endy) ?
+              cy + ximagesrc->cursor_image->height - starty :
+              ximagesrc->endy - starty;
         }
       } else {
         startx = cx;
@@ -812,11 +735,11 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
               GUINT_TO_LE (ximagesrc->cursor_image->pixels[i]);
         /* copy those pixels across */
         for (j = starty;
-            j < starty + iheight
-            && j < ximagesrc->starty + ximagesrc->height; j++) {
+            j < starty + iheight && j < ximagesrc->starty + ximagesrc->height;
+            j++) {
           for (i = startx;
-              i < startx + iwidth
-              && i < ximagesrc->startx + ximagesrc->width; i++) {
+              i < startx + iwidth && i < ximagesrc->startx + ximagesrc->width;
+              i++) {
             guint8 *src, *dest;
 
             src =
@@ -825,8 +748,8 @@ gst_ximage_src_ximage_get (GstXImageSrc * ximagesrc)
             dest =
                 (guint8 *) & (meta->ximage->data[((j -
                             ximagesrc->starty) * ximagesrc->width + (i -
-                            ximagesrc->startx)) *
-                    (ximagesrc->xcontext->bpp / 8)]);
+                            ximagesrc->startx)) * (ximagesrc->xcontext->bpp /
+                        8)]);
 
             composite_pixel (ximagesrc->xcontext, (guint8 *) dest,
                 (guint8 *) src);
@@ -860,6 +783,12 @@ gst_ximage_src_create (GstPushSrc * bs, GstBuffer ** buf)
   GstClockTime dur;
   gint64 next_frame_no;
 
+  if (!gst_ximage_src_recalc (s)) {
+    GST_ELEMENT_ERROR (s, RESOURCE, FAILED,
+        (_("Changing resolution at runtime is not yet supported.")), (NULL));
+    return GST_FLOW_ERROR;
+  }
+
   if (s->fps_n <= 0 || s->fps_d <= 0)
     return GST_FLOW_NOT_NEGOTIATED;     /* FPS must be > 0 */
 
@@ -928,25 +857,12 @@ gst_ximage_src_create (GstPushSrc * bs, GstBuffer ** buf)
   s->last_frame_no = next_frame_no;
   GST_OBJECT_UNLOCK (s);
 
-  XGrabServer (s->xcontext->disp);
-
-  if (gst_ximage_src_recalc (s) && !gst_base_src_negotiate (GST_BASE_SRC (s))) {
-    XUngrabServer (s->xcontext->disp);
-    XSync (s->xcontext->disp, False);
-    return GST_FLOW_NOT_NEGOTIATED;
-  }
-
   image = gst_ximage_src_ximage_get (s);
-
-  XUngrabServer (s->xcontext->disp);
-  XSync (s->xcontext->disp, False);
-
   if (!image)
     return GST_FLOW_ERROR;
 
   *buf = image;
-  GST_BUFFER_DTS (*buf) = GST_CLOCK_TIME_NONE;
-  GST_BUFFER_PTS (*buf) = next_capture_ts;
+  GST_BUFFER_TIMESTAMP (*buf) = next_capture_ts;
   GST_BUFFER_DURATION (*buf) = dur;
 
   return GST_FLOW_OK;
@@ -960,8 +876,12 @@ gst_ximage_src_set_property (GObject * object, guint prop_id,
 
   switch (prop_id) {
     case PROP_DISPLAY_NAME:
+
       g_free (src->display_name);
-      src->display_name = g_value_dup_string (value);
+      src->display_name = g_strdup (g_value_get_string (value));
+      break;
+    case PROP_SCREEN_NUM:
+      src->screen_num = g_value_get_uint (value);
       break;
     case PROP_SHOW_POINTER:
       src->show_pointer = g_value_get_boolean (value);
@@ -977,13 +897,9 @@ gst_ximage_src_set_property (GObject * object, guint prop_id,
       break;
     case PROP_ENDX:
       src->endx = g_value_get_uint (value);
-      /* property comments say 0 means right/bottom, means we can't capture
-       * the top left pixel alone */
-      src->endx_fit_to_screen = (src->endx == 0);
       break;
     case PROP_ENDY:
       src->endy = g_value_get_uint (value);
-      src->endy_fit_to_screen = (src->endy == 0);
       break;
     case PROP_REMOTE:
       src->remote = g_value_get_boolean (value);
@@ -1001,10 +917,7 @@ gst_ximage_src_set_property (GObject * object, guint prop_id,
         break;
       }
       g_free (src->xname);
-      src->xname = g_value_dup_string (value);
-      break;
-    case PROP_ENABLE_NAVIGATION_EVENTS:
-      src->enable_navigation_events = g_value_get_boolean (value);
+      src->xname = g_strdup (g_value_get_string (value));
       break;
     default:
       break;
@@ -1012,8 +925,8 @@ gst_ximage_src_set_property (GObject * object, guint prop_id,
 }
 
 static void
-gst_ximage_src_get_property (GObject * object, guint prop_id,
-    GValue * value, GParamSpec * pspec)
+gst_ximage_src_get_property (GObject * object, guint prop_id, GValue * value,
+    GParamSpec * pspec)
 {
   GstXImageSrc *src = GST_XIMAGE_SRC (object);
 
@@ -1023,6 +936,10 @@ gst_ximage_src_get_property (GObject * object, guint prop_id,
         g_value_set_string (value, DisplayString (src->xcontext->disp));
       else
         g_value_set_string (value, src->display_name);
+
+      break;
+    case PROP_SCREEN_NUM:
+      g_value_set_uint (value, src->screen_num);
       break;
     case PROP_SHOW_POINTER:
       g_value_set_boolean (value, src->show_pointer);
@@ -1051,9 +968,6 @@ gst_ximage_src_get_property (GObject * object, guint prop_id,
     case PROP_XNAME:
       g_value_set_string (value, src->xname);
       break;
-    case PROP_ENABLE_NAVIGATION_EVENTS:
-      g_value_set_boolean (value, src->enable_navigation_events);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -1092,7 +1006,6 @@ gst_ximage_src_finalize (GObject * object)
   if (src->xcontext)
     ximageutil_xcontext_clear (src->xcontext);
 
-  g_free (src->display_name);
   g_free (src->xname);
   g_mutex_clear (&src->pool_lock);
   g_mutex_clear (&src->x_lock);
@@ -1107,26 +1020,36 @@ gst_ximage_src_get_caps (GstBaseSrc * bs, GstCaps * filter)
   GstXContext *xcontext;
   gint width, height;
   GstVideoFormat format;
-  guint32 alpha_mask;
 
   if ((!s->xcontext) && (!gst_ximage_src_open_display (s, s->display_name)))
     return gst_pad_get_pad_template_caps (GST_BASE_SRC (s)->srcpad);
 
-  gst_ximage_src_recalc (s);
+  if (!gst_ximage_src_recalc (s))
+    return gst_pad_get_pad_template_caps (GST_BASE_SRC (s)->srcpad);
 
   xcontext = s->xcontext;
-  width = s->xwin_width;
-  height = s->xwin_height;
+  width = s->xcontext->width;
+  height = s->xcontext->height;
+  if (s->xwindow != 0) {
+    XWindowAttributes attrs;
+    int status = XGetWindowAttributes (s->xcontext->disp, s->xwindow, &attrs);
+    if (status) {
+      width = attrs.width;
+      height = attrs.height;
+    }
+  }
 
-  if (s->endx_fit_to_screen)
+  /* property comments say 0 means right/bottom, means we can't capture
+     the top left pixel alone */
+  if (s->endx == 0)
     s->endx = width - 1;
-  if (s->endy_fit_to_screen)
+  if (s->endy == 0)
     s->endy = height - 1;
 
   if (s->endx >= s->startx && s->endy >= s->starty) {
     /* this means user has put in values */
-    if (s->startx < width && s->endx < width &&
-        s->starty < height && s->endy < height) {
+    if (s->startx < xcontext->width && s->endx < xcontext->width &&
+        s->starty < xcontext->height && s->endy < xcontext->height) {
       /* values are fine */
       s->width = width = s->endx - s->startx + 1;
       s->height = height = s->endy - s->starty + 1;
@@ -1137,8 +1060,6 @@ gst_ximage_src_get_caps (GstBaseSrc * bs, GstCaps * filter)
       s->starty = 0;
       s->endx = width - 1;
       s->endy = height - 1;
-      s->endx_fit_to_screen = FALSE;
-      s->endy_fit_to_screen = FALSE;
     }
   } else {
     GST_WARNING ("User put in bogus co-ordinates, setting to full screen");
@@ -1146,31 +1067,21 @@ gst_ximage_src_get_caps (GstBaseSrc * bs, GstCaps * filter)
     s->starty = 0;
     s->endx = width - 1;
     s->endy = height - 1;
-    s->endx_fit_to_screen = FALSE;
-    s->endy_fit_to_screen = FALSE;
   }
   GST_DEBUG ("width = %d, height=%d", width, height);
 
-  /* extrapolate alpha mask */
-  if (xcontext->depth == 32) {
-    alpha_mask = ~(xcontext->r_mask_output
-        | xcontext->g_mask_output | xcontext->b_mask_output);
-  } else {
-    alpha_mask = 0;
-  }
-
   format =
       gst_video_format_from_masks (xcontext->depth, xcontext->bpp,
-      xcontext->endianness, xcontext->r_mask_output,
-      xcontext->g_mask_output, xcontext->b_mask_output, alpha_mask);
+      xcontext->endianness, xcontext->r_mask_output, xcontext->g_mask_output,
+      xcontext->b_mask_output, 0);
 
   return gst_caps_new_simple ("video/x-raw",
       "format", G_TYPE_STRING, gst_video_format_to_string (format),
       "width", G_TYPE_INT, width,
       "height", G_TYPE_INT, height,
       "framerate", GST_TYPE_FRACTION_RANGE, 1, G_MAXINT, G_MAXINT, 1,
-      "pixel-aspect-ratio", GST_TYPE_FRACTION, xcontext->par_n,
-      xcontext->par_d, NULL);
+      "pixel-aspect-ratio", GST_TYPE_FRACTION, xcontext->par_n, xcontext->par_d,
+      NULL);
 }
 
 static gboolean
@@ -1217,72 +1128,6 @@ gst_ximage_src_fixate (GstBaseSrc * bsrc, GstCaps * caps)
   return caps;
 }
 
-static gboolean
-gst_ximage_src_event (GstBaseSrc * base_src, GstEvent * event)
-{
-  gboolean ret = FALSE;
-#ifdef HAVE_XNAVIGATION
-  gboolean is_press = FALSE;
-  GstXImageSrc *src = GST_XIMAGE_SRC (base_src);
-  if (src->enable_navigation_events
-      && GST_EVENT_TYPE (event) == GST_EVENT_NAVIGATION) {
-    const gchar *key;
-    gint button;
-    gdouble x, y, delta_x, delta_y;
-
-    GST_DEBUG_OBJECT (src, "Processing event %" GST_PTR_FORMAT, event);
-    switch (gst_navigation_event_get_type (event)) {
-      case GST_NAVIGATION_EVENT_KEY_PRESS:
-        is_press = TRUE;        /* FALLTHROUGH */
-      case GST_NAVIGATION_EVENT_KEY_RELEASE:
-        if (gst_navigation_event_parse_key_event (event, &key)) {
-          gst_ximage_navigation_key (src->xcontext->disp, key, is_press);
-          ret = TRUE;
-        }
-        break;
-      case GST_NAVIGATION_EVENT_MOUSE_BUTTON_PRESS:
-        is_press = TRUE;        /* FALLTHROUGH */
-      case GST_NAVIGATION_EVENT_MOUSE_BUTTON_RELEASE:
-        if (gst_navigation_event_parse_mouse_button_event (event, &button, &x,
-                &y)) {
-          gst_ximage_navigation_mouse_push_button (src->xcontext->disp, button,
-              is_press);
-          ret = TRUE;
-        }
-        break;
-      case GST_NAVIGATION_EVENT_MOUSE_MOVE:
-        if (gst_navigation_event_parse_mouse_move_event (event, &x, &y)) {
-          gst_ximage_navigation_mouse_move_pointer (src->xcontext->disp,
-              (int) x, (int) y);
-          ret = TRUE;
-        }
-        break;
-      case GST_NAVIGATION_EVENT_MOUSE_SCROLL:
-        if (gst_navigation_event_parse_mouse_scroll_event (event, &x, &y,
-                &delta_x, &delta_y)) {
-          int scroll_button =
-              (int) delta_y <
-              0 ? MOUSE_SCROLL_DOWN_BUTTON : MOUSE_SCROLL_UP_BUTTON;
-          gst_ximage_navigation_mouse_push_button (src->xcontext->disp,
-              scroll_button, TRUE);
-          gst_ximage_navigation_mouse_push_button (src->xcontext->disp,
-              scroll_button, FALSE);
-          ret = TRUE;
-        }
-        break;
-      default:
-        break;
-    }
-  }
-#endif
-  if (!ret) {
-    ret =
-        GST_CALL_PARENT_WITH_DEFAULT (GST_BASE_SRC_CLASS, event, (base_src,
-            event), FALSE);
-  }
-  return ret;
-}
-
 static void
 gst_ximage_src_class_init (GstXImageSrcClass * klass)
 {
@@ -1297,109 +1142,117 @@ gst_ximage_src_class_init (GstXImageSrcClass * klass)
   gc->finalize = gst_ximage_src_finalize;
 
   g_object_class_install_property (gc, PROP_DISPLAY_NAME,
-      g_param_spec_string ("display-name", "Display", "X Display Name",
-          NULL, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+      g_param_spec_string ("display-name", "Display", "X Display Name", NULL,
+          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+  g_object_class_install_property (gc, PROP_SCREEN_NUM,
+      g_param_spec_uint ("screen-num", "Screen number", "X Screen Number",
+          0, G_MAXINT, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   g_object_class_install_property (gc, PROP_SHOW_POINTER,
       g_param_spec_boolean ("show-pointer", "Show Mouse Pointer",
           "Show mouse pointer (if XFixes extension enabled)", TRUE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstXImageSrc:use-damage:
+   * GstXImageSrc:use-damage
    *
    * Use XDamage (if the XDamage extension is enabled)
-   */
+   *
+   * Since: 0.10.4
+   **/
   g_object_class_install_property (gc, PROP_USE_DAMAGE,
       g_param_spec_boolean ("use-damage", "Use XDamage",
           "Use XDamage (if XDamage extension enabled)", TRUE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstXImageSrc:startx:
+   * GstXImageSrc:startx
    *
    * X coordinate of top left corner of area to be recorded
    * (0 for top left of screen)
-   */
+   *
+   * Since: 0.10.4
+   **/
   g_object_class_install_property (gc, PROP_STARTX,
       g_param_spec_uint ("startx", "Start X co-ordinate",
           "X coordinate of top left corner of area to be recorded (0 for top left of screen)",
           0, G_MAXINT, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstXImageSrc:starty:
+   * GstXImageSrc:starty
    *
    * Y coordinate of top left corner of area to be recorded
    * (0 for top left of screen)
-   */
+   *
+   * Since: 0.10.4
+   **/
   g_object_class_install_property (gc, PROP_STARTY,
       g_param_spec_uint ("starty", "Start Y co-ordinate",
           "Y coordinate of top left corner of area to be recorded (0 for top left of screen)",
-          0, G_MAXINT, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+          0, G_MAXINT, 0, G_PARAM_READWRITE));
   /**
-   * GstXImageSrc:endx:
+   * GstXImageSrc:endx
    *
    * X coordinate of bottom right corner of area to be recorded
    * (0 for bottom right of screen)
-   */
+   *
+   * Since: 0.10.4
+   **/
   g_object_class_install_property (gc, PROP_ENDX,
       g_param_spec_uint ("endx", "End X",
           "X coordinate of bottom right corner of area to be recorded (0 for bottom right of screen)",
-          0, G_MAXINT, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+          0, G_MAXINT, 0, G_PARAM_READWRITE));
   /**
-   * GstXImageSrc:endy:
+   * GstXImageSrc:endy
    *
    * Y coordinate of bottom right corner of area to be recorded
    * (0 for bottom right of screen)
-   */
+   *
+   * Since: 0.10.4
+   **/
   g_object_class_install_property (gc, PROP_ENDY,
       g_param_spec_uint ("endy", "End Y",
           "Y coordinate of bottom right corner of area to be recorded (0 for bottom right of screen)",
-          0, G_MAXINT, 0, G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+          0, G_MAXINT, 0, G_PARAM_READWRITE));
 
   /**
-   * GstXImageSrc:remote:
+   * GstXImageSrc:remote
    *
    * Whether the X display is remote. The element will try to use alternate calls
    * known to work better with remote displays.
-   */
+   *
+   * Since: 0.10.26
+   **/
   g_object_class_install_property (gc, PROP_REMOTE,
-      g_param_spec_boolean ("remote", "Remote display",
+      g_param_spec_boolean ("remote", "Remote dispay",
           "Whether the display is remote", FALSE,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstXImageSrc:xid:
+   * GstXImageSrc:xid
    *
    * The XID of the window to capture. 0 for the root window (default).
-   */
+   *
+   * Since: 0.10.31
+   **/
   g_object_class_install_property (gc, PROP_XID,
       g_param_spec_uint64 ("xid", "Window XID",
           "Window XID to capture from", 0, G_MAXUINT64, 0,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
   /**
-   * GstXImageSrc:xname:
+   * GstXImageSrc:xname
    *
    * The name of the window to capture, if any.
-   */
+   *
+   * Since: 0.10.31
+   **/
   g_object_class_install_property (gc, PROP_XNAME,
       g_param_spec_string ("xname", "Window name",
           "Window name to capture from", NULL,
           G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
-  /**
-   * GstXImageSrc:enable-navigation-events:
-   *
-   * Enable navigation events
-   */
-  g_object_class_install_property (gc, PROP_ENABLE_NAVIGATION_EVENTS,
-      g_param_spec_boolean ("enable-navigation-events",
-          "Enable navigation events",
-          "When enabled, navigation events are handled", FALSE,
-          G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
-
   gst_element_class_set_static_metadata (ec, "Ximage video source",
       "Source/Video",
       "Creates a screenshot video stream",
       "Lutz Mueller <lutz@users.sourceforge.net>, "
       "Jan Schmidt <thaytan@mad.scientist.com>, "
       "Zaheer Merali <zaheerabbas at merali dot org>");
-  gst_element_class_add_static_pad_template (ec, &t);
+  gst_element_class_add_pad_template (ec, gst_static_pad_template_get (&t));
 
   bc->fixate = gst_ximage_src_fixate;
   bc->get_caps = gst_ximage_src_get_caps;
@@ -1408,10 +1261,6 @@ gst_ximage_src_class_init (GstXImageSrcClass * klass)
   bc->stop = gst_ximage_src_stop;
   bc->unlock = gst_ximage_src_unlock;
   push_class->create = gst_ximage_src_create;
-  bc->event = gst_ximage_src_event;
-
-  GST_DEBUG_CATEGORY_INIT (gst_debug_ximage_src, "ximagesrc", 0,
-      "ximagesrc element debug");
 }
 
 static void
@@ -1428,10 +1277,7 @@ gst_ximage_src_init (GstXImageSrc * ximagesrc)
   ximagesrc->starty = 0;
   ximagesrc->endx = 0;
   ximagesrc->endy = 0;
-  ximagesrc->endx_fit_to_screen = TRUE;
-  ximagesrc->endy_fit_to_screen = TRUE;
   ximagesrc->remote = FALSE;
-  ximagesrc->enable_navigation_events = FALSE;
 }
 
 static gboolean
@@ -1439,8 +1285,8 @@ plugin_init (GstPlugin * plugin)
 {
   gboolean ret;
 
-  if (g_getenv ("GST_XINITTHREADS"))
-    XInitThreads ();
+  GST_DEBUG_CATEGORY_INIT (gst_debug_ximage_src, "ximagesrc", 0,
+      "ximagesrc element debug");
 
   ret = gst_element_register (plugin, "ximagesrc", GST_RANK_NONE,
       GST_TYPE_XIMAGE_SRC);
