@@ -2,7 +2,6 @@
  * Copyright (C) 2006-2007 Tim-Philipp Müller <tim centricular net>
  * Copyright (C) 2008 Wouter Cloetens <wouter@mind.be>
  * Copyright (C) 2001-2003, Ximian, Inc.
- * Copyright (C) 2021 Igalia S.L.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -16,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,45 +27,16 @@
 
 #include <glib.h>
 #include <glib/gprintf.h>
-
-#include <libsoup/soup.h>
+#include <libsoup/soup-address.h>
+#include <libsoup/soup-message.h>
+#include <libsoup/soup-misc.h>
+#include <libsoup/soup-server.h>
+#include <libsoup/soup-auth-domain.h>
+#include <libsoup/soup-auth-domain-basic.h>
+#include <libsoup/soup-auth-domain-digest.h>
 #include <gst/check/gstcheck.h>
 
-#if ! SOUP_CHECK_VERSION(3, 0, 0)
-#if !defined(SOUP_MINOR_VERSION) || SOUP_MINOR_VERSION < 44
-#define SoupStatus SoupKnownStatusCode
-#endif
-#endif
-
-#if SOUP_CHECK_VERSION(3, 0, 0)
-
-#define SOUP_AUTH_DOMAIN_BASIC_AUTH_CALLBACK "auth-callback"
-#define SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK "auth-callback"
-
-#define gst_soup_uri_free g_uri_unref
-#define gst_soup_uri_to_string(x) g_uri_to_string_partial(x, G_URI_HIDE_PASSWORD)
-#define gst_soup_uri_get_port(x) g_uri_get_port(x)
-
-#else
-
-#define gst_soup_uri_free soup_uri_free
-#define gst_soup_uri_to_string(x) soup_uri_to_string(x, FALSE)
-#define gst_soup_uri_get_port(x) soup_uri_get_port(x)
-
-#define SoupServerMessage SoupMessage
-
-#define soup_server_message_get_method(x) (x->method)
-#define soup_server_message_get_http_version(x) soup_message_get_http_version(x)
-#define soup_server_message_get_status(x) (x->status_code)
-#define soup_server_message_set_status(x, s, r) soup_message_set_status(x, s)
-#define soup_server_message_get_reason_phrase(x) (x->reason_phrase)
-#define soup_server_message_get_uri(x) soup_message_get_uri(x)
-#define soup_server_message_get_request_headers(x) (x->request_headers)
-#define soup_server_message_get_response_headers(x) (x->response_headers)
-#define soup_server_message_get_request_body(x) (x->request_body)
-#define soup_server_message_get_response_body(x) (x->response_body)
-
-#endif
+static guint http_port = 0, https_port = 0;
 
 gboolean redirect = TRUE;
 
@@ -83,11 +53,8 @@ static const char *realm = "SOUPHTTPSRC_REALM";
 static const char *basic_auth_path = "/basic_auth";
 static const char *digest_auth_path = "/digest_auth";
 
-static const char *ssl_cert_file = GST_TEST_FILES_PATH "/test-cert.pem";
-static const char *ssl_key_file = GST_TEST_FILES_PATH "/test-key.pem";
-
-static guint get_port_from_server (SoupServer * server);
-static SoupServer *run_server (gboolean use_https);
+static int run_server (guint * http_port, guint * https_port);
+static void stop_server (void);
 
 static void
 handoff_cb (GstElement * fakesink, GstBuffer * buf, GstPad * pad,
@@ -118,24 +85,22 @@ digest_auth_cb (SoupAuthDomain * domain, SoupMessage * msg,
   return NULL;
 }
 
-static gboolean
-run_test (gboolean use_https, const gchar * path, gint expected)
+static int
+run_test (const char *format, ...)
 {
   GstStateChangeReturn ret;
-  GstElement *pipe, *src, *sink;
-  GstBuffer *buf = NULL;
-  GstMessage *msg;
-  gchar *url;
-  gboolean res = FALSE;
-  SoupServer *server;
-  guint port;
 
-  server = run_server (use_https);
-  if (server == NULL) {
-    g_print ("Failed to start up %s server", use_https ? "HTTPS" : "HTTP");
-    /* skip this test */
-    return TRUE;
-  }
+  GstElement *pipe, *src, *sink;
+
+  GstBuffer *buf = NULL;
+
+  GstMessage *msg;
+
+  gchar *url;
+
+  va_list args;
+
+  int rc = -1;
 
   pipe = gst_pipeline_new (NULL);
 
@@ -149,37 +114,17 @@ run_test (gboolean use_https, const gchar * path, gint expected)
   gst_bin_add (GST_BIN (pipe), sink);
   fail_unless (gst_element_link (src, sink));
 
-  port = get_port_from_server (server);
-  url = g_strdup_printf ("%s://127.0.0.1:%u%s",
-      use_https ? "https" : "http", port, path);
+  if (http_port == 0) {
+    GST_DEBUG ("failed to start soup http server");
+  }
+  fail_unless (http_port != 0);
+  va_start (args, format);
+  g_vasprintf (&url, format, args);
+  va_end (args);
   fail_unless (url != NULL);
   g_object_set (src, "location", url, NULL);
   g_free (url);
 
-  if (use_https) {
-    GTlsDatabase *tlsdb;
-    GError *error = NULL;
-    gchar *path;
-
-    /* GTlsFileDatabase needs an absolute path. Using a relative one
-     * causes a warning from GLib-Net followed by a segfault in GnuTLS */
-    if (g_path_is_absolute (ssl_cert_file)) {
-      path = g_strdup (ssl_cert_file);
-    } else {
-      gchar *cwd = g_get_current_dir ();
-      path = g_build_filename (cwd, ssl_cert_file, NULL);
-      g_free (cwd);
-    }
-
-    tlsdb = g_tls_file_database_new (path, &error);
-    fail_unless (tlsdb, "Failed to load certificate: %s", error->message);
-
-    g_object_set (src, "tls-database", tlsdb, NULL);
-
-    g_object_unref (tlsdb);
-    g_free (path);
-  }
-
   g_object_set (src, "automatic-redirect", redirect, NULL);
   if (cookies != NULL)
     g_object_set (src, "cookies", cookies, NULL);
@@ -202,8 +147,8 @@ run_test (gboolean use_https, const gchar * path, gint expected)
       GST_MESSAGE_EOS | GST_MESSAGE_ERROR, -1);
   if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_ERROR) {
     gchar *debug = NULL;
+
     GError *err = NULL;
-    gint rc = -1;
 
     gst_message_parse_error (msg, &err, &debug);
     GST_INFO ("error: %s", err->message);
@@ -216,16 +161,9 @@ run_test (gboolean use_https, const gchar * path, gint expected)
     else if (g_str_has_suffix (err->message, "Found"))
       rc = 302;
     GST_INFO ("debug: %s", debug);
-    /* should not've gotten any output in case of a 40x error. Wait a bit
-     * to give the streaming thread a chance to push out a buffer and trigger
-     * our callback before shutting down the pipeline */
-    g_usleep (G_USEC_PER_SEC / 2);
-    fail_unless (buf == NULL);
     g_error_free (err);
     g_free (debug);
     gst_message_unref (msg);
-    GST_DEBUG ("Got HTTP error %u, expected %u", rc, expected);
-    res = (rc == expected);
     goto done;
   }
   gst_message_unref (msg);
@@ -239,7 +177,6 @@ run_test (gboolean use_https, const gchar * path, gint expected)
      * it might be for lots of reasons (no network connection, whatever), we're
      * not interested in those */
     GST_DEBUG ("didn't manage to get data within 10 seconds, skipping test");
-    res = TRUE;
     goto done;
   }
 
@@ -248,34 +185,32 @@ run_test (gboolean use_https, const gchar * path, gint expected)
   /* first buffer should have a 0 offset */
   fail_unless (GST_BUFFER_OFFSET (buf) == 0);
   gst_buffer_unref (buf);
-  res = (expected == 0);
+  rc = 0;
 
 done:
 
   gst_element_set_state (pipe, GST_STATE_NULL);
   gst_object_unref (pipe);
-  gst_object_unref (server);
-  return res;
+  return rc;
 }
 
 GST_START_TEST (test_first_buffer_has_offset)
 {
-  fail_unless (run_test (FALSE, "/", 0));
+  fail_unless (run_test ("http://127.0.0.1:%u/", http_port) == 0);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_not_found)
 {
-  fail_unless (run_test (FALSE, "/404", 404));
-  fail_unless (run_test (FALSE, "/404-with-data", 404));
+  fail_unless (run_test ("http://127.0.0.1:%u/404", http_port) == 404);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_forbidden)
 {
-  fail_unless (run_test (FALSE, "/403", 403));
+  fail_unless (run_test ("http://127.0.0.1:%u/403", http_port) == 403);
 }
 
 GST_END_TEST;
@@ -283,7 +218,7 @@ GST_END_TEST;
 GST_START_TEST (test_redirect_no)
 {
   redirect = FALSE;
-  fail_unless (run_test (FALSE, "/302", 302));
+  fail_unless (run_test ("http://127.0.0.1:%u/302", http_port) == 302);
 }
 
 GST_END_TEST;
@@ -291,14 +226,17 @@ GST_END_TEST;
 GST_START_TEST (test_redirect_yes)
 {
   redirect = TRUE;
-  fail_unless (run_test (FALSE, "/302", 0));
+  fail_unless (run_test ("http://127.0.0.1:%u/302", http_port) == 0);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_https)
 {
-  fail_unless (run_test (TRUE, "/", 0));
+  if (!https_port)
+    GST_INFO ("Failed to start an HTTPS server; let's just skip this test.");
+  else
+    fail_unless (run_test ("https://127.0.0.1:%u/", https_port) == 0);
 }
 
 GST_END_TEST;
@@ -306,96 +244,96 @@ GST_END_TEST;
 GST_START_TEST (test_cookies)
 {
   static const char *biscotti[] = { "delacre=yummie", "koekje=lu", NULL };
-  gboolean res;
+  int rc;
 
   cookies = biscotti;
-  res = run_test (FALSE, "/", 0);
+  rc = run_test ("http://127.0.0.1:%u/", http_port);
   cookies = NULL;
-  fail_unless (res);
+  fail_unless (rc == 0);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_good_user_basic_auth)
 {
-  gboolean res;
+  int res;
 
   user_id = good_user;
   user_pw = good_pw;
-  res = run_test (FALSE, basic_auth_path, 0);
+  res = run_test ("http://127.0.0.1:%u%s", http_port, basic_auth_path);
   GST_DEBUG ("Basic Auth user %s password %s res = %d", user_id, user_pw, res);
   user_id = user_pw = NULL;
-  fail_unless (res);
+  fail_unless (res == 0);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_bad_user_basic_auth)
 {
-  gboolean res;
+  int res;
 
   user_id = bad_user;
   user_pw = good_pw;
-  res = run_test (FALSE, basic_auth_path, 401);
+  res = run_test ("http://127.0.0.1:%u%s", http_port, basic_auth_path);
   GST_DEBUG ("Basic Auth user %s password %s res = %d", user_id, user_pw, res);
   user_id = user_pw = NULL;
-  fail_unless (res);
+  fail_unless (res == 401);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_bad_password_basic_auth)
 {
-  gboolean res;
+  int res;
 
   user_id = good_user;
   user_pw = bad_pw;
-  res = run_test (FALSE, basic_auth_path, 401);
+  res = run_test ("http://127.0.0.1:%u%s", http_port, basic_auth_path);
   GST_DEBUG ("Basic Auth user %s password %s res = %d", user_id, user_pw, res);
   user_id = user_pw = NULL;
-  fail_unless (res);
+  fail_unless (res == 401);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_good_user_digest_auth)
 {
-  gboolean res;
+  int res;
 
   user_id = good_user;
   user_pw = good_pw;
-  res = run_test (FALSE, digest_auth_path, 0);
+  res = run_test ("http://127.0.0.1:%u%s", http_port, digest_auth_path);
   GST_DEBUG ("Digest Auth user %s password %s res = %d", user_id, user_pw, res);
   user_id = user_pw = NULL;
-  fail_unless (res);
+  fail_unless (res == 0);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_bad_user_digest_auth)
 {
-  gboolean res;
+  int res;
 
   user_id = bad_user;
   user_pw = good_pw;
-  res = run_test (FALSE, digest_auth_path, 401);
+  res = run_test ("http://127.0.0.1:%u%s", http_port, digest_auth_path);
   GST_DEBUG ("Digest Auth user %s password %s res = %d", user_id, user_pw, res);
   user_id = user_pw = NULL;
-  fail_unless (res);
+  fail_unless (res == 401);
 }
 
 GST_END_TEST;
 
 GST_START_TEST (test_bad_password_digest_auth)
 {
-  gboolean res;
+  int res;
 
   user_id = good_user;
   user_pw = bad_pw;
-  res = run_test (FALSE, digest_auth_path, 401);
+  res = run_test ("http://127.0.0.1:%u%s", http_port, digest_auth_path);
   GST_DEBUG ("Digest Auth user %s password %s res = %d", user_id, user_pw, res);
   user_id = user_pw = NULL;
-  fail_unless (res);
+  fail_unless (res == 401);
 }
 
 GST_END_TEST;
@@ -441,9 +379,33 @@ GST_START_TEST (test_icy_stream)
   gst_bin_add (GST_BIN (pipe), sink);
   fail_unless (gst_element_link (src, sink));
 
-  /* Radionomy Hot40Music shoutcast stream */
-  g_object_set (src, "location",
-      "http://streaming.radionomy.com:80/Hot40Music", NULL);
+  /* First try Virgin Radio Ogg stream, to see if there's connectivity and all
+   * (which is an attempt to work around the completely horrid error reporting
+   * and that we can't distinguish different types of failures here). */
+
+  g_object_set (src, "location", "http://ogg2.smgradio.com/vr32.ogg", NULL);
+  g_object_set (src, "num-buffers", 1, NULL);
+  icy_caps = FALSE;
+  gst_element_set_state (pipe, GST_STATE_PLAYING);
+
+  msg = gst_bus_poll (GST_ELEMENT_BUS (pipe),
+      GST_MESSAGE_EOS | GST_MESSAGE_ERROR, -1);
+  if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_ERROR) {
+    GST_INFO ("looks like there's no net connectivity or sgmradio.com is "
+        "down. In any case, let's just skip this test");
+    gst_message_unref (msg);
+    goto done;
+  }
+  gst_message_unref (msg);
+  msg = NULL;
+  gst_element_set_state (pipe, GST_STATE_NULL);
+
+  /* Now, if the ogg stream works, the mp3 shoutcast stream should work as
+   * well (time will tell if that's true) */
+
+  /* Virgin Radio 32kbps mp3 shoutcast stream */
+  g_object_set (src, "location", "http://mp3-vr-32.smgradio.com:80/", NULL);
+
 
   /* EOS after the first buffer */
   g_object_set (src, "num-buffers", 1, NULL);
@@ -452,24 +414,22 @@ GST_START_TEST (test_icy_stream)
   msg = gst_bus_poll (GST_ELEMENT_BUS (pipe),
       GST_MESSAGE_EOS | GST_MESSAGE_ERROR, -1);
 
-  switch (GST_MESSAGE_TYPE (msg)) {
-    case GST_MESSAGE_EOS:
-      GST_DEBUG ("success, we're done here");
-      gst_message_unref (msg);
-      break;
-    case GST_MESSAGE_ERROR:{
-      GError *err = NULL;
-
-      gst_message_parse_error (msg, &err, NULL);
-      GST_INFO ("Error with ICY mp3 shoutcast stream: %s", err->message);
-      gst_message_unref (msg);
-      g_clear_error (&err);
-      break;
-    }
-    default:
-      break;
+  if (GST_MESSAGE_TYPE (msg) == GST_MESSAGE_EOS) {
+    GST_DEBUG ("success, we're done here");
+    gst_message_unref (msg);
+    goto done;
   }
 
+  {
+    GError *err = NULL;
+
+    gst_message_parse_error (msg, &err, NULL);
+    gst_message_unref (msg);
+    g_error ("Error with ICY mp3 shoutcast stream: %s", err->message);
+    g_error_free (err);
+  }
+
+done:
   icy_caps = FALSE;
 
   gst_element_set_state (pipe, GST_STATE_NULL);
@@ -481,19 +441,17 @@ GST_END_TEST;
 static Suite *
 souphttpsrc_suite (void)
 {
-  TCase *tc_chain, *tc_internet;
   Suite *s;
 
-  /* we don't support exceptions from the proxy, so just unset the environment
-   * variable - in case it's set in the test environment it would otherwise
-   * prevent us from connecting to localhost (like jenkins.qa.ubuntu.com) */
-  g_unsetenv ("http_proxy");
+  TCase *tc_chain, *tc_internet;
 
   s = suite_create ("souphttpsrc");
   tc_chain = tcase_create ("general");
   tc_internet = tcase_create ("internet");
 
   suite_add_tcase (s, tc_chain);
+  run_server (&http_port, &https_port);
+  atexit (stop_server);
   tcase_add_test (tc_chain, test_first_buffer_has_offset);
   tcase_add_test (tc_chain, test_redirect_yes);
   tcase_add_test (tc_chain, test_redirect_no);
@@ -506,7 +464,8 @@ souphttpsrc_suite (void)
   tcase_add_test (tc_chain, test_good_user_digest_auth);
   tcase_add_test (tc_chain, test_bad_user_digest_auth);
   tcase_add_test (tc_chain, test_bad_password_digest_auth);
-  tcase_add_test (tc_chain, test_https);
+  if (soup_ssl_supported)
+    tcase_add_test (tc_chain, test_https);
 
   suite_add_tcase (s, tc_internet);
   tcase_set_timeout (tc_internet, 250);
@@ -518,16 +477,15 @@ souphttpsrc_suite (void)
 GST_CHECK_MAIN (souphttpsrc);
 
 static void
-do_get (SoupServerMessage * msg, const char *path)
+do_get (SoupMessage * msg, const char *path)
 {
-  gboolean send_error_doc = FALSE;
   char *uri;
 
   int buflen = 4096;
 
-  SoupStatus status = SOUP_STATUS_OK;
+  SoupKnownStatusCode status = SOUP_STATUS_OK;
 
-  uri = gst_soup_uri_to_string (soup_server_message_get_uri (msg));
+  uri = soup_uri_to_string (soup_message_get_uri (msg), FALSE);
   GST_DEBUG ("request: \"%s\"", uri);
 
   if (!strcmp (path, "/301"))
@@ -540,30 +498,25 @@ do_get (SoupServerMessage * msg, const char *path)
     status = SOUP_STATUS_FORBIDDEN;
   else if (!strcmp (path, "/404"))
     status = SOUP_STATUS_NOT_FOUND;
-  else if (!strcmp (path, "/404-with-data")) {
-    status = SOUP_STATUS_NOT_FOUND;
-    send_error_doc = TRUE;
-  }
 
   if (SOUP_STATUS_IS_REDIRECTION (status)) {
     char *redir_uri;
 
     redir_uri = g_strdup_printf ("%s-redirected", uri);
-    soup_message_headers_append (soup_server_message_get_response_headers (msg),
-        "Location", redir_uri);
+    soup_message_headers_append (msg->response_headers, "Location", redir_uri);
     g_free (redir_uri);
   }
-  if (status != (SoupStatus) SOUP_STATUS_OK && !send_error_doc)
+  if (status != SOUP_STATUS_OK)
     goto leave;
 
-  if (soup_server_message_get_method (msg) == SOUP_METHOD_GET) {
+  if (msg->method == SOUP_METHOD_GET) {
     char *buf;
 
     buf = g_malloc (buflen);
     memset (buf, 0, buflen);
-    soup_message_body_append (soup_server_message_get_response_body (msg),
-        SOUP_MEMORY_TAKE, buf, buflen);
-  } else {                      /* method == SOUP_METHOD_HEAD */
+    soup_message_body_append (msg->response_body, SOUP_MEMORY_TAKE,
+        buf, buflen);
+  } else {                      /* msg->method == SOUP_METHOD_HEAD */
 
     char *length;
 
@@ -572,13 +525,13 @@ do_get (SoupServerMessage * msg, const char *path)
      * malloc.
      */
     length = g_strdup_printf ("%lu", (gulong) buflen);
-    soup_message_headers_append (soup_server_message_get_response_headers (msg),
+    soup_message_headers_append (msg->response_headers,
         "Content-Length", length);
     g_free (length);
   }
 
 leave:
-  soup_server_message_set_status (msg, status, NULL);
+  soup_message_set_status (msg, status);
   g_free (uri);
 }
 
@@ -589,146 +542,93 @@ print_header (const char *name, const char *value, gpointer data)
 }
 
 static void
-server_callback (SoupServer * server, SoupServerMessage * msg,
+server_callback (SoupServer * server, SoupMessage * msg,
     const char *path, GHashTable * query,
-#if !SOUP_CHECK_VERSION(3, 0, 0)
-    SoupClientContext * context,
-#endif
-    gpointer data)
+    SoupClientContext * context, gpointer data)
 {
-  const char *method = soup_server_message_get_method (msg);
+  GST_DEBUG ("%s %s HTTP/1.%d", msg->method, path,
+      soup_message_get_http_version (msg));
+  soup_message_headers_foreach (msg->request_headers, print_header, NULL);
+  if (msg->request_body->length)
+    GST_DEBUG ("%s", msg->request_body->data);
 
-  GST_DEBUG ("%s %s HTTP/1.%d", method, path,
-      soup_server_message_get_http_version (msg));
-  soup_message_headers_foreach (soup_server_message_get_request_headers (msg),
-      print_header, NULL);
-  if (soup_server_message_get_request_body (msg)->length)
-    GST_DEBUG ("%s", soup_server_message_get_request_body (msg)->data);
-
-  if (method == SOUP_METHOD_GET || method == SOUP_METHOD_HEAD)
+  if (msg->method == SOUP_METHOD_GET || msg->method == SOUP_METHOD_HEAD)
     do_get (msg, path);
   else
-    soup_server_message_set_status (msg, SOUP_STATUS_NOT_IMPLEMENTED, NULL);
+    soup_message_set_status (msg, SOUP_STATUS_NOT_IMPLEMENTED);
 
-  GST_DEBUG ("  -> %d %s", soup_server_message_get_status (msg),
-      soup_server_message_get_reason_phrase (msg));
+  GST_DEBUG ("  -> %d %s", msg->status_code, msg->reason_phrase);
 }
 
-static guint
-get_port_from_server (SoupServer * server)
+static SoupServer *server;      /* NULL */
+static SoupServer *ssl_server;  /* NULL */
+
+int
+run_server (guint * http_port, guint * https_port)
 {
-  GSList *uris;
-  guint port;
+  guint port = SOUP_ADDRESS_ANY_PORT;
+  guint ssl_port = SOUP_ADDRESS_ANY_PORT;
+  const char *ssl_cert_file = GST_TEST_FILES_PATH "/test-cert.pem";
+  const char *ssl_key_file = GST_TEST_FILES_PATH "/test-key.pem";
+  static int server_running = 0;
 
-  uris = soup_server_get_uris (server);
-  fail_unless_equals_uint64 (g_slist_length (uris), 1);
-  port = gst_soup_uri_get_port (uris->data);
-  g_slist_free_full (uris, (GDestroyNotify) gst_soup_uri_free);
+  SoupAuthDomain *domain = NULL;
 
-  return port;
-}
+  if (server_running)
+    return 0;
+  server_running = 1;
 
-static SoupServer *
-run_server (gboolean use_https)
-{
-  SoupServer *server = soup_server_new (NULL, NULL);
-  SoupServerListenOptions listen_flags = 0;
-  guint port;
+  *http_port = *https_port = 0;
 
-
-  if (use_https) {
-    GTlsBackend *backend = g_tls_backend_get_default ();
-    GError *err = NULL;
-
-    if (backend == NULL || !g_tls_backend_supports_tls (backend)) {
-      GST_INFO ("No TLS support");
-      g_object_unref (server);
-      return NULL;
-    }
-#if SOUP_CHECK_VERSION(3, 0, 0)
-    {
-      GTlsCertificate *cert =
-          g_tls_certificate_new_from_files (ssl_cert_file, ssl_key_file,
-          &err);
-      if (!cert) {
-        GST_INFO ("Failed to load certificate: %s", err->message);
-        g_error_free (err);
-        return NULL;
-      }
-      soup_server_set_tls_certificate (server, cert);
-      g_object_unref (cert);
-    }
-#else
-    if (!soup_server_set_ssl_cert_file (server, ssl_cert_file, ssl_key_file,
-            &err)) {
-      GST_INFO ("Failed to load certificate: %s", err->message);
-      g_object_unref (server);
-      g_error_free (err);
-      return NULL;
-    }
-#endif
-
-    listen_flags |= SOUP_SERVER_LISTEN_HTTPS;
+  server = soup_server_new (SOUP_SERVER_PORT, port, NULL);
+  if (!server) {
+    GST_DEBUG ("Unable to bind to server port %u", port);
+    return 1;
   }
-
+  *http_port = soup_server_get_port (server);
+  GST_INFO ("HTTP server listening on port %u", *http_port);
   soup_server_add_handler (server, NULL, server_callback, NULL, NULL);
+  domain = soup_auth_domain_basic_new (SOUP_AUTH_DOMAIN_REALM, realm,
+      SOUP_AUTH_DOMAIN_BASIC_AUTH_CALLBACK, basic_auth_cb,
+      SOUP_AUTH_DOMAIN_ADD_PATH, basic_auth_path, NULL);
+  soup_server_add_auth_domain (server, domain);
+  g_object_unref (domain);
+  domain = soup_auth_domain_digest_new (SOUP_AUTH_DOMAIN_REALM, realm,
+      SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK, digest_auth_cb,
+      SOUP_AUTH_DOMAIN_ADD_PATH, digest_auth_path, NULL);
+  soup_server_add_auth_domain (server, domain);
+  g_object_unref (domain);
+  soup_server_run_async (server);
 
-  {
-    SoupAuthDomain *domain;
+  if (ssl_cert_file && ssl_key_file) {
+    ssl_server = soup_server_new (SOUP_SERVER_PORT, ssl_port,
+        SOUP_SERVER_SSL_CERT_FILE, ssl_cert_file,
+        SOUP_SERVER_SSL_KEY_FILE, ssl_key_file, NULL);
 
-    domain = soup_auth_domain_basic_new ("realm", realm,
-        SOUP_AUTH_DOMAIN_BASIC_AUTH_CALLBACK, basic_auth_cb, NULL);
-    soup_auth_domain_add_path (domain, basic_auth_path);
-    soup_server_add_auth_domain (server, domain);
-    g_object_unref (domain);
-
-    domain = soup_auth_domain_digest_new ("realm", realm,
-        SOUP_AUTH_DOMAIN_DIGEST_AUTH_CALLBACK, digest_auth_cb, NULL);
-    soup_auth_domain_add_path (domain, digest_auth_path);
-    soup_server_add_auth_domain (server, domain);
-    g_object_unref (domain);
-  }
-
-  {
-    GSocketAddress *address;
-    GError *err = NULL;
-
-    address = g_inet_socket_address_new_from_string ("0.0.0.0", 0);
-    soup_server_listen (server, address, listen_flags, &err);
-    g_object_unref (address);
-
-    if (err) {
-      GST_ERROR ("Failed to start %s server: %s",
-          use_https ? "HTTPS" : "HTTP", err->message);
-      g_object_unref (server);
-      g_error_free (err);
-      return NULL;
+    if (!ssl_server) {
+      GST_DEBUG ("Unable to bind to SSL server port %u", ssl_port);
+      return 1;
     }
+    *https_port = soup_server_get_port (ssl_server);
+    GST_INFO ("HTTPS server listening on port %u", *https_port);
+    soup_server_add_handler (ssl_server, NULL, server_callback, NULL, NULL);
+    soup_server_run_async (ssl_server);
   }
 
-  port = get_port_from_server (server);
-  GST_DEBUG ("%s server listening on port %u", use_https ? "HTTPS" : "HTTP",
-      port);
+  return 0;
+}
 
-  /* check if we can connect to our local http server */
-  {
-    GSocketConnection *conn;
-    GSocketClient *client;
+static void
+stop_server (void)
+{
+  GST_INFO ("cleaning up");
 
-    client = g_socket_client_new ();
-    g_socket_client_set_timeout (client, 2);
-    conn =
-        g_socket_client_connect_to_host (client, "127.0.0.1", port, NULL, NULL);
-    if (conn == NULL) {
-      GST_INFO ("Couldn't connect to 127.0.0.1:%u", port);
-      g_object_unref (client);
-      g_object_unref (server);
-      return NULL;
-    }
-
-    g_object_unref (conn);
-    g_object_unref (client);
+  if (server) {
+    g_object_unref (server);
+    server = NULL;
+  }
+  if (ssl_server) {
+    g_object_unref (ssl_server);
+    ssl_server = NULL;
   }
-
-  return server;
 }
