@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,6 +25,8 @@
 # include <valgrind/valgrind.h>
 #endif
 
+#include <unistd.h>
+
 #include <gst/check/gstcheck.h>
 #include <gst/video/video.h>
 #include <gst/base/gstbasetransform.h>
@@ -49,15 +51,10 @@ video_crop_get_test_caps (GstElement * videocrop)
   for (i = 0; i < gst_caps_get_size (allowed_caps); ++i) {
     GstStructure *new_structure;
     GstCaps *single_caps;
-    GstStructure *structure;
-
-    /* featured caps don't describe format: skip them */
-    structure = gst_caps_get_structure (allowed_caps, i);
-    if (!gst_structure_has_field (structure, "format"))
-      continue;
 
     single_caps = gst_caps_new_empty ();
-    new_structure = gst_structure_copy (structure);
+    new_structure =
+        gst_structure_copy (gst_caps_get_structure (allowed_caps, i));
     gst_structure_set (new_structure, "framerate", GST_TYPE_FRACTION,
         1, 1, NULL);
     gst_structure_remove_field (new_structure, "width");
@@ -99,14 +96,14 @@ GST_START_TEST (test_unit_sizes)
       gint width, height;
     } sizes_to_try[] = {
       {
-          160, 120}, {
-          161, 120}, {
-          160, 121}, {
-          161, 121}, {
-          159, 120}, {
-          160, 119}, {
-          159, 119}, {
-          159, 121}
+      160, 120}, {
+      161, 120}, {
+      160, 121}, {
+      161, 121}, {
+      159, 120}, {
+      160, 119}, {
+      159, 119}, {
+      159, 121}
     };
     GstStructure *s;
     GstCaps *caps;
@@ -163,7 +160,6 @@ typedef struct
   GstElement *src;
   GstElement *filter;
   GstElement *crop;
-  GstElement *filter2;
   GstElement *sink;
   GstBuffer *last_buf;
   GstCaps *last_caps;
@@ -182,46 +178,30 @@ handoff_cb (GstElement * sink, GstBuffer * buf, GstPad * pad,
 }
 
 static void
-videocrop_test_cropping_init_context_full (GstVideoCropTestContext * ctx,
-    gboolean featured)
+videocrop_test_cropping_init_context (GstVideoCropTestContext * ctx)
 {
   fail_unless (ctx != NULL);
 
   ctx->pipeline = gst_pipeline_new ("pipeline");
   fail_unless (ctx->pipeline != NULL);
-
-  if (featured)
-    ctx->src = gst_element_factory_make ("fakesrc", "src");
-  else
-    ctx->src = gst_element_factory_make ("videotestsrc", "src");
+  ctx->src = gst_element_factory_make ("videotestsrc", "src");
   fail_unless (ctx->src != NULL, "Failed to create videotestsrc element");
   ctx->filter = gst_element_factory_make ("capsfilter", "filter");
   fail_unless (ctx->filter != NULL, "Failed to create capsfilter element");
   ctx->crop = gst_element_factory_make ("videocrop", "crop");
   fail_unless (ctx->crop != NULL, "Failed to create videocrop element");
-  ctx->filter2 = gst_element_factory_make ("capsfilter", "filter2");
-  fail_unless (ctx->filter2 != NULL,
-      "Failed to create second capsfilter element");
   ctx->sink = gst_element_factory_make ("fakesink", "sink");
   fail_unless (ctx->sink != NULL, "Failed to create fakesink element");
 
   gst_bin_add_many (GST_BIN (ctx->pipeline), ctx->src, ctx->filter,
-      ctx->crop, ctx->filter2, ctx->sink, NULL);
-  gst_element_link_many (ctx->src, ctx->filter, ctx->crop, ctx->filter2,
-      ctx->sink, NULL);
+      ctx->crop, ctx->sink, NULL);
+  gst_element_link_many (ctx->src, ctx->filter, ctx->crop, ctx->sink, NULL);
 
-  if (featured) {
-    g_object_set (ctx->src, "format", GST_FORMAT_TIME, NULL);
-  } else {
-    /* set pattern to 'red' - for our purposes it doesn't matter anyway */
-    g_object_set (ctx->src, "pattern", 4, NULL);
-  }
+  /* set pattern to 'red' - for our purposes it doesn't matter anyway */
+  g_object_set (ctx->src, "pattern", 4, NULL);
 
-  if (!featured) {
-    g_object_set (ctx->sink, "signal-handoffs", TRUE, NULL);
-    g_signal_connect (ctx->sink, "preroll-handoff", G_CALLBACK (handoff_cb),
-        ctx);
-  }
+  g_object_set (ctx->sink, "signal-handoffs", TRUE, NULL);
+  g_signal_connect (ctx->sink, "preroll-handoff", G_CALLBACK (handoff_cb), ctx);
 
   ctx->last_buf = NULL;
   ctx->last_caps = NULL;
@@ -229,12 +209,6 @@ videocrop_test_cropping_init_context_full (GstVideoCropTestContext * ctx,
   GST_LOG ("context inited");
 }
 
-static void
-videocrop_test_cropping_init_context (GstVideoCropTestContext * ctx)
-{
-  videocrop_test_cropping_init_context_full (ctx, FALSE);
-}
-
 static void
 videocrop_test_cropping_deinit_context (GstVideoCropTestContext * ctx)
 {
@@ -251,15 +225,13 @@ typedef void (*GstVideoCropTestBufferFunc) (GstBuffer * buffer, GstCaps * caps);
 
 static void
 videocrop_test_cropping (GstVideoCropTestContext * ctx, GstCaps * in_caps,
-    GstCaps * out_caps, gint left, gint right, gint top, gint bottom,
+    gint left, gint right, gint top, gint bottom,
     GstVideoCropTestBufferFunc func)
 {
-  GST_LOG ("lrtb = %03u %03u %03u %03u, in_caps = %" GST_PTR_FORMAT
-      ", out_caps = %" GST_PTR_FORMAT, left, right, top, bottom, in_caps,
-      out_caps);
+  GST_LOG ("lrtb = %03u %03u %03u %03u, caps = %" GST_PTR_FORMAT, left, right,
+      top, bottom, in_caps);
 
   g_object_set (ctx->filter, "caps", in_caps, NULL);
-  g_object_set (ctx->filter2, "caps", out_caps, NULL);
 
   g_object_set (ctx->crop, "left", left, "right", right, "top", top,
       "bottom", bottom, NULL);
@@ -286,8 +258,7 @@ check_1x1_buffer (GstBuffer * buf, GstCaps * caps)
   /* the exact values we check for come from videotestsrc */
   static const guint yuv_values[] = { 81, 90, 240, 255 };
   static const guint rgb_values[] = { 0xff, 0, 0, 255 };
-  static const guint gray8_values[] = { 0x51 };
-  static const guint gray16_values[] = { 0x5151 };
+  static const guint gray_values[] = { 0x51 };
   const guint *values;
   guint i;
   const GstVideoFormatInfo *finfo;
@@ -303,10 +274,7 @@ check_1x1_buffer (GstBuffer * buf, GstCaps * caps)
   if (GST_VIDEO_INFO_IS_YUV (&info))
     values = yuv_values;
   else if (GST_VIDEO_INFO_IS_GRAY (&info))
-    if (GST_VIDEO_FORMAT_INFO_BITS (finfo) == 8)
-      values = gray8_values;
-    else
-      values = gray16_values;
+    values = gray_values;
   else
     values = rgb_values;
 
@@ -341,11 +309,7 @@ check_1x1_buffer (GstBuffer * buf, GstCaps * caps)
       val = val & ((1 << depth) - 1);
 
       GST_DEBUG ("val %08x %d : %d", pixels, i, val);
-      if (depth <= 8) {
-        fail_unless_equals_int (val, values[i] >> (8 - depth));
-      } else {
-        fail_unless_equals_int (val, values[i] >> (16 - depth));
-      }
+      fail_unless_equals_int (val, values[i] >> (8 - depth));
     } else {
     }
   }
@@ -381,12 +345,11 @@ GST_START_TEST (test_crop_to_1x1)
     gst_structure_set (s, "width", G_TYPE_INT, 160,
         "height", G_TYPE_INT, 160, NULL);
 
-    videocrop_test_cropping (&ctx, caps, NULL, 159, 0, 159, 0,
-        check_1x1_buffer);
+    videocrop_test_cropping (&ctx, caps, 159, 0, 159, 0, check_1x1_buffer);
     /* commented out because they don't really add anything useful check-wise:
-       videocrop_test_cropping (&ctx, caps, NULL, 0, 159, 0, 159, check_1x1_buffer);
-       videocrop_test_cropping (&ctx, caps, NULL, 159, 0, 0, 159, check_1x1_buffer);
-       videocrop_test_cropping (&ctx, caps, NULL, 0, 159, 159, 0, check_1x1_buffer);
+       videocrop_test_cropping (&ctx, caps, 0, 159, 0, 159, check_1x1_buffer);
+       videocrop_test_cropping (&ctx, caps, 159, 0, 0, 159, check_1x1_buffer);
+       videocrop_test_cropping (&ctx, caps, 0, 159, 159, 0, check_1x1_buffer);
      */
     gst_caps_unref (caps);
   }
@@ -406,14 +369,14 @@ GST_START_TEST (test_cropping)
     gint width, height;
   } sizes_to_try[] = {
     {
-        160, 160}, {
-        161, 160}, {
-        160, 161}, {
-        161, 161}, {
-        159, 160}, {
-        160, 159}, {
-        159, 159}, {
-        159, 161}
+    160, 160}, {
+    161, 160}, {
+    160, 161}, {
+    161, 161}, {
+    159, 160}, {
+    160, 159}, {
+    159, 159}, {
+    159, 161}
   };
   GList *caps_list, *node;
   gint i;
@@ -434,7 +397,7 @@ GST_START_TEST (test_cropping)
     GST_INFO ("testing format: %" GST_PTR_FORMAT, caps);
 
     for (i = 0; i < G_N_ELEMENTS (sizes_to_try); ++i) {
-      GstCaps *in_caps, *out_caps;
+      GstCaps *in_caps;
 
       GST_INFO (" - %d x %d", sizes_to_try[i].width, sizes_to_try[i].height);
 
@@ -442,51 +405,29 @@ GST_START_TEST (test_cropping)
           "height", G_TYPE_INT, sizes_to_try[i].height, NULL);
       in_caps = gst_caps_copy (caps);
 
-      gst_structure_set (s, "width", G_TYPE_INT, 1, "height", G_TYPE_INT, 1,
-          NULL);
-      out_caps = gst_caps_copy (caps);
-
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 0, 0, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 1, 0, 0, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 1, 0, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 0, 1, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 0, 0, 1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 63, 0, 0, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 63, 0, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 0, 63, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 0, 0, 63, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 63, 0, 0, 1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 63, 1, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 1, 63, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 1, 0, 0, 63, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 0, 0, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 32, 0, 0, 128, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 32, 128, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 0, 128, 32, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 128, 0, 0, 32, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 1, 1, 1, 1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 63, 63, 63, 63, NULL);
-      videocrop_test_cropping (&ctx, in_caps, NULL, 64, 64, 64, 64, NULL);
-
-      /* Dynamic cropping */
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1, -1, -1, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, 0, -1, -1, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1, 0, -1, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1, -1, 0, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1, -1, -1, 0, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, 10, -1, 10, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1, 10, -1, 10, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps,
-          sizes_to_try[i].width - 1, -1, -1, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1,
-          sizes_to_try[i].width - 1, -1, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1, -1,
-          sizes_to_try[i].height - 1, -1, NULL);
-      videocrop_test_cropping (&ctx, in_caps, out_caps, -1, -1, -1,
-          sizes_to_try[i].height - 1, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 0, 0, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 1, 0, 0, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 1, 0, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 0, 1, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 0, 0, 1, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 63, 0, 0, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 63, 0, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 0, 63, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 0, 0, 63, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 63, 0, 0, 1, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 63, 1, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 1, 63, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 1, 0, 0, 63, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 0, 0, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 32, 0, 0, 128, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 32, 128, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 0, 128, 32, 0, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 128, 0, 0, 32, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 1, 1, 1, 1, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 63, 63, 63, 63, NULL);
+      videocrop_test_cropping (&ctx, in_caps, 64, 64, 64, 64, NULL);
 
       gst_caps_unref (in_caps);
-      gst_caps_unref (out_caps);
     }
 
     gst_caps_unref (caps);
@@ -809,94 +750,6 @@ GST_START_TEST (test_caps_transform)
 
 GST_END_TEST;
 
-static GstCaps *
-get_featured_caps (void)
-{
-  GstCaps *caps;
-  GstCapsFeatures *features;
-
-  features = gst_caps_features_new_static_str ("memory:DMABuf", NULL);
-  caps = gst_caps_new_simple ("video/x-raw",
-      "format", G_TYPE_STRING, "NV12",
-      "framerate", GST_TYPE_FRACTION, 1, 1,
-      "width", G_TYPE_INT, 200, "height", G_TYPE_INT, 100, NULL);
-  gst_caps_set_features_simple (caps, features);
-
-  return caps;
-}
-
-GST_START_TEST (test_caps_transform_featured)
-{
-  GstVideoCropTestContext ctx;
-  GstBaseTransformClass *klass;
-  GstBaseTransform *crop;
-  GstCaps *caps, *adj_caps;
-
-  videocrop_test_cropping_init_context (&ctx);
-
-  caps = get_featured_caps ();
-
-  crop = GST_BASE_TRANSFORM (ctx.crop);
-  klass = GST_BASE_TRANSFORM_GET_CLASS (ctx.crop);
-  fail_unless (klass != NULL);
-
-  /* by default, it should be no cropping and hence passthrough */
-  adj_caps = klass->transform_caps (crop, GST_PAD_SRC, caps, NULL);
-  fail_unless (adj_caps != NULL);
-
-  fail_unless (gst_caps_is_equal (adj_caps, caps));
-  gst_caps_unref (adj_caps);
-
-  adj_caps = klass->transform_caps (crop, GST_PAD_SINK, caps, NULL);
-  fail_unless (adj_caps != NULL);
-  fail_unless (gst_caps_is_equal (adj_caps, caps));
-  gst_caps_unref (adj_caps);
-
-  /* make sure that's still true after changing properties back and forth */
-  g_object_set (ctx.crop, "left", 1, "right", 3, "top", 5, "bottom", 7, NULL);
-  g_object_set (ctx.crop, "left", 0, "right", 0, "top", 0, "bottom", 0, NULL);
-
-  adj_caps = klass->transform_caps (crop, GST_PAD_SRC, caps, NULL);
-  fail_unless (adj_caps != NULL);
-  fail_unless (gst_caps_is_equal (adj_caps, caps));
-  gst_caps_unref (adj_caps);
-
-  adj_caps = klass->transform_caps (crop, GST_PAD_SINK, caps, NULL);
-  fail_unless (adj_caps != NULL);
-  fail_unless (gst_caps_is_equal (adj_caps, caps));
-  gst_caps_unref (adj_caps);
-
-  gst_caps_unref (caps);
-  videocrop_test_cropping_deinit_context (&ctx);
-}
-
-GST_END_TEST;
-
-GST_START_TEST (test_passthrough_featured)
-{
-  GstStateChangeReturn state_ret;
-  GstVideoCropTestContext ctx;
-  GstCaps *caps;
-
-  videocrop_test_cropping_init_context_full (&ctx, TRUE);
-
-  g_object_set (ctx.src, "num-buffers", 1, NULL);
-
-  caps = get_featured_caps ();
-  g_object_set (ctx.filter, "caps", caps, NULL);
-  gst_caps_unref (caps);
-
-  g_object_set (ctx.crop, "left", 50, "top", 10, NULL);
-
-  state_ret = gst_element_set_state (ctx.pipeline, GST_STATE_PAUSED);
-  fail_unless (state_ret == GST_STATE_CHANGE_ASYNC,
-      "pipeline should fail on negotiation");
-
-  videocrop_test_cropping_deinit_context (&ctx);
-}
-
-GST_END_TEST;
-
 static Suite *
 videocrop_suite (void)
 {
@@ -918,13 +771,26 @@ videocrop_suite (void)
   suite_add_tcase (s, tc_chain);
   tcase_add_test (tc_chain, test_crop_to_1x1);
   tcase_add_test (tc_chain, test_caps_transform);
-  tcase_add_test (tc_chain, test_caps_transform_featured);
   tcase_add_test (tc_chain, test_passthrough);
-  tcase_add_test (tc_chain, test_passthrough_featured);
   tcase_add_test (tc_chain, test_unit_sizes);
   tcase_add_loop_test (tc_chain, test_cropping, 0, 25);
 
   return s;
 }
 
-GST_CHECK_MAIN (videocrop);
+int
+main (int argc, char **argv)
+{
+  int nf;
+
+  Suite *s = videocrop_suite ();
+  SRunner *sr = srunner_create (s);
+
+  gst_check_init (&argc, &argv);
+
+  srunner_run_all (sr, CK_NORMAL);
+  nf = srunner_ntests_failed (sr);
+  srunner_free (sr);
+
+  return nf;
+}
