@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
- * Boston, MA 02110-1301, USA.
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
  */
 
 /* FIXME 0.11: suppress warnings for deprecated API such as GValueArray
@@ -108,7 +108,7 @@ print_stats (GstElement * rtpbin)
 
 /* build a pipeline equivalent to:
  *
- * gst-launch-1.0 -v rtpbin name=rtpbin \
+ * gst-launch -v rtpbin name=rtpbin \
  *    $AUDIO_SRC ! audioconvert ! audioresample ! $AUDIO_ENC ! $AUDIO_PAY ! rtpbin.send_rtp_sink_0  \
  *           rtpbin.send_rtp_src_0 ! udpsink port=5002 host=$DEST                      \
  *           rtpbin.send_rtcp_src_0 ! udpsink port=5003 host=$DEST sync=false async=false \
@@ -177,7 +177,7 @@ main (int argc, char *argv[])
   gst_bin_add_many (GST_BIN (pipeline), rtpsink, rtcpsink, rtcpsrc, NULL);
 
   /* now link all to the rtpbin, start by getting an RTP sinkpad for session 0 */
-  sinkpad = gst_element_request_pad_simple (rtpbin, "send_rtp_sink_0");
+  sinkpad = gst_element_get_request_pad (rtpbin, "send_rtp_sink_0");
   srcpad = gst_element_get_static_pad (audiopay, "src");
   if (gst_pad_link (srcpad, sinkpad) != GST_PAD_LINK_OK)
     g_error ("Failed to link audio payloader to rtpbin");
@@ -193,7 +193,7 @@ main (int argc, char *argv[])
   gst_object_unref (sinkpad);
 
   /* get an RTCP srcpad for sending RTCP to the receiver */
-  srcpad = gst_element_request_pad_simple (rtpbin, "send_rtcp_src_0");
+  srcpad = gst_element_get_request_pad (rtpbin, "send_rtcp_src_0");
   sinkpad = gst_element_get_static_pad (rtcpsink, "sink");
   if (gst_pad_link (srcpad, sinkpad) != GST_PAD_LINK_OK)
     g_error ("Failed to link rtpbin to rtcpsink");
@@ -202,7 +202,7 @@ main (int argc, char *argv[])
   /* we also want to receive RTCP, request an RTCP sinkpad for session 0 and
    * link it to the srcpad of the udpsrc for RTCP */
   srcpad = gst_element_get_static_pad (rtcpsrc, "src");
-  sinkpad = gst_element_request_pad_simple (rtpbin, "recv_rtcp_sink_0");
+  sinkpad = gst_element_get_request_pad (rtpbin, "recv_rtcp_sink_0");
   if (gst_pad_link (srcpad, sinkpad) != GST_PAD_LINK_OK)
     g_error ("Failed to link rtcpsrc to rtpbin");
   gst_object_unref (srcpad);
@@ -212,7 +212,7 @@ main (int argc, char *argv[])
   gst_element_set_state (pipeline, GST_STATE_PLAYING);
 
   /* print stats every second */
-  g_timeout_add_seconds (1, (GSourceFunc) print_stats, rtpbin);
+  g_timeout_add (1000, (GSourceFunc) print_stats, rtpbin);
 
   /* we need to run a GLib main loop to get the messages */
   loop = g_main_loop_new (NULL, FALSE);
